# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_AVERAGE_ROI_CORRELATION_METADATA = Metadata(
    id="539e96c2fb64bff82d21688d1bec36d954413c34.boutiques",
    name="cifti-average-roi-correlation",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiAverageRoiCorrelationCiftiRoiParameters = typing.TypedDict('CiftiAverageRoiCorrelationCiftiRoiParameters', {
    "@type": typing.NotRequired[typing.Literal["cifti_roi"]],
    "roi_cifti": InputPathType,
    "opt_in_memory": bool,
})
CiftiAverageRoiCorrelationCiftiRoiParametersTagged = typing.TypedDict('CiftiAverageRoiCorrelationCiftiRoiParametersTagged', {
    "@type": typing.Literal["cifti_roi"],
    "roi_cifti": InputPathType,
    "opt_in_memory": bool,
})


CiftiAverageRoiCorrelationCiftiParameters = typing.TypedDict('CiftiAverageRoiCorrelationCiftiParameters', {
    "@type": typing.NotRequired[typing.Literal["cifti"]],
    "cifti_in": InputPathType,
})
CiftiAverageRoiCorrelationCiftiParametersTagged = typing.TypedDict('CiftiAverageRoiCorrelationCiftiParametersTagged', {
    "@type": typing.Literal["cifti"],
    "cifti_in": InputPathType,
})


CiftiAverageRoiCorrelationParameters = typing.TypedDict('CiftiAverageRoiCorrelationParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-average-roi-correlation"]],
    "cifti_out": str,
    "cifti_roi": typing.NotRequired[CiftiAverageRoiCorrelationCiftiRoiParameters | None],
    "opt_left_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_right_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_vol_roi_roi_vol": typing.NotRequired[InputPathType | None],
    "opt_left_area_surf_left_surf": typing.NotRequired[InputPathType | None],
    "opt_right_area_surf_right_surf": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_area_surf_cerebellum_surf": typing.NotRequired[InputPathType | None],
    "cifti": typing.NotRequired[list[CiftiAverageRoiCorrelationCiftiParameters] | None],
})
CiftiAverageRoiCorrelationParametersTagged = typing.TypedDict('CiftiAverageRoiCorrelationParametersTagged', {
    "@type": typing.Literal["workbench/cifti-average-roi-correlation"],
    "cifti_out": str,
    "cifti_roi": typing.NotRequired[CiftiAverageRoiCorrelationCiftiRoiParameters | None],
    "opt_left_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_right_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_vol_roi_roi_vol": typing.NotRequired[InputPathType | None],
    "opt_left_area_surf_left_surf": typing.NotRequired[InputPathType | None],
    "opt_right_area_surf_right_surf": typing.NotRequired[InputPathType | None],
    "opt_cerebellum_area_surf_cerebellum_surf": typing.NotRequired[InputPathType | None],
    "cifti": typing.NotRequired[list[CiftiAverageRoiCorrelationCiftiParameters] | None],
})


def cifti_average_roi_correlation_cifti_roi_params(
    roi_cifti: InputPathType,
    opt_in_memory: bool = False,
) -> CiftiAverageRoiCorrelationCiftiRoiParametersTagged:
    """
    Build parameters.
    
    Args:
        roi_cifti: the roi cifti file.
        opt_in_memory: cache the roi in memory so that it isn't re-read for\
            each input cifti.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cifti_roi",
        "roi_cifti": roi_cifti,
        "opt_in_memory": opt_in_memory,
    }
    return params


def cifti_average_roi_correlation_cifti_roi_cargs(
    params: CiftiAverageRoiCorrelationCiftiRoiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cifti-roi")
    cargs.append(execution.input_file(params.get("roi_cifti", None)))
    if params.get("opt_in_memory", False):
        cargs.append("-in-memory")
    return cargs


def cifti_average_roi_correlation_cifti_params(
    cifti_in: InputPathType,
) -> CiftiAverageRoiCorrelationCiftiParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: a cifti file to average across.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "cifti",
        "cifti_in": cifti_in,
    }
    return params


def cifti_average_roi_correlation_cifti_cargs(
    params: CiftiAverageRoiCorrelationCiftiParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-cifti")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    return cargs


class CiftiAverageRoiCorrelationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiAverageRoiCorrelationParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """output cifti file"""


def cifti_average_roi_correlation_params(
    cifti_out: str,
    cifti_roi: CiftiAverageRoiCorrelationCiftiRoiParameters | None = None,
    opt_left_roi_roi_metric: InputPathType | None = None,
    opt_right_roi_roi_metric: InputPathType | None = None,
    opt_cerebellum_roi_roi_metric: InputPathType | None = None,
    opt_vol_roi_roi_vol: InputPathType | None = None,
    opt_left_area_surf_left_surf: InputPathType | None = None,
    opt_right_area_surf_right_surf: InputPathType | None = None,
    opt_cerebellum_area_surf_cerebellum_surf: InputPathType | None = None,
    cifti: list[CiftiAverageRoiCorrelationCiftiParameters] | None = None,
) -> CiftiAverageRoiCorrelationParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_out: output cifti file.
        cifti_roi: cifti file containing combined weights.
        opt_left_roi_roi_metric: weights to use for left hempsphere: the left\
            roi as a metric file.
        opt_right_roi_roi_metric: weights to use for right hempsphere: the\
            right roi as a metric file.
        opt_cerebellum_roi_roi_metric: weights to use for cerebellum surface:\
            the cerebellum roi as a metric file.
        opt_vol_roi_roi_vol: voxel weights to use: the roi volume file.
        opt_left_area_surf_left_surf: specify the left surface for vertex area\
            correction: the left surface file.
        opt_right_area_surf_right_surf: specify the right surface for vertex\
            area correction: the right surface file.
        opt_cerebellum_area_surf_cerebellum_surf: specify the cerebellum\
            surface for vertex area correction: the cerebellum surface file.
        cifti: specify an input cifti file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-average-roi-correlation",
        "cifti_out": cifti_out,
    }
    if cifti_roi is not None:
        params["cifti_roi"] = cifti_roi
    if opt_left_roi_roi_metric is not None:
        params["opt_left_roi_roi_metric"] = opt_left_roi_roi_metric
    if opt_right_roi_roi_metric is not None:
        params["opt_right_roi_roi_metric"] = opt_right_roi_roi_metric
    if opt_cerebellum_roi_roi_metric is not None:
        params["opt_cerebellum_roi_roi_metric"] = opt_cerebellum_roi_roi_metric
    if opt_vol_roi_roi_vol is not None:
        params["opt_vol_roi_roi_vol"] = opt_vol_roi_roi_vol
    if opt_left_area_surf_left_surf is not None:
        params["opt_left_area_surf_left_surf"] = opt_left_area_surf_left_surf
    if opt_right_area_surf_right_surf is not None:
        params["opt_right_area_surf_right_surf"] = opt_right_area_surf_right_surf
    if opt_cerebellum_area_surf_cerebellum_surf is not None:
        params["opt_cerebellum_area_surf_cerebellum_surf"] = opt_cerebellum_area_surf_cerebellum_surf
    if cifti is not None:
        params["cifti"] = cifti
    return params


def cifti_average_roi_correlation_cargs(
    params: CiftiAverageRoiCorrelationParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-average-roi-correlation")
    cargs.append(params.get("cifti_out", None))
    if params.get("cifti_roi", None) is not None:
        cargs.extend(cifti_average_roi_correlation_cifti_roi_cargs(params.get("cifti_roi", None), execution))
    if params.get("opt_left_roi_roi_metric", None) is not None:
        cargs.extend([
            "-left-roi",
            execution.input_file(params.get("opt_left_roi_roi_metric", None))
        ])
    if params.get("opt_right_roi_roi_metric", None) is not None:
        cargs.extend([
            "-right-roi",
            execution.input_file(params.get("opt_right_roi_roi_metric", None))
        ])
    if params.get("opt_cerebellum_roi_roi_metric", None) is not None:
        cargs.extend([
            "-cerebellum-roi",
            execution.input_file(params.get("opt_cerebellum_roi_roi_metric", None))
        ])
    if params.get("opt_vol_roi_roi_vol", None) is not None:
        cargs.extend([
            "-vol-roi",
            execution.input_file(params.get("opt_vol_roi_roi_vol", None))
        ])
    if params.get("opt_left_area_surf_left_surf", None) is not None:
        cargs.extend([
            "-left-area-surf",
            execution.input_file(params.get("opt_left_area_surf_left_surf", None))
        ])
    if params.get("opt_right_area_surf_right_surf", None) is not None:
        cargs.extend([
            "-right-area-surf",
            execution.input_file(params.get("opt_right_area_surf_right_surf", None))
        ])
    if params.get("opt_cerebellum_area_surf_cerebellum_surf", None) is not None:
        cargs.extend([
            "-cerebellum-area-surf",
            execution.input_file(params.get("opt_cerebellum_area_surf_cerebellum_surf", None))
        ])
    if params.get("cifti", None) is not None:
        cargs.extend([a for c in [cifti_average_roi_correlation_cifti_cargs(s, execution) for s in params.get("cifti", None)] for a in c])
    return cargs


def cifti_average_roi_correlation_outputs(
    params: CiftiAverageRoiCorrelationParameters,
    execution: Execution,
) -> CiftiAverageRoiCorrelationOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiAverageRoiCorrelationOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_average_roi_correlation_execute(
    params: CiftiAverageRoiCorrelationParameters,
    runner: Runner | None = None,
) -> CiftiAverageRoiCorrelationOutputs:
    """
    cifti-average-roi-correlation
    
    Correlate roi average with all rows then average across subjects.
    
    Averages rows for each map of the ROI(s), takes the correlation of each ROI
    average to the rest of the rows in the same file, applies the fisher small z
    transform, then averages the results across all files. ROIs are always
    treated as weighting functions, including negative values. For efficiency,
    ensure that everything that is not intended to be used is zero in the ROI
    map. If -cifti-roi is specified, -left-roi, -right-roi, -cerebellum-roi, and
    -vol-roi must not be specified. If multiple non-cifti ROI files are
    specified, they must have the same number of columns.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiAverageRoiCorrelationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_AVERAGE_ROI_CORRELATION_METADATA)
    params = execution.params(params)
    cargs = cifti_average_roi_correlation_cargs(params, execution)
    ret = cifti_average_roi_correlation_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_average_roi_correlation(
    cifti_out: str,
    cifti_roi: CiftiAverageRoiCorrelationCiftiRoiParameters | None = None,
    opt_left_roi_roi_metric: InputPathType | None = None,
    opt_right_roi_roi_metric: InputPathType | None = None,
    opt_cerebellum_roi_roi_metric: InputPathType | None = None,
    opt_vol_roi_roi_vol: InputPathType | None = None,
    opt_left_area_surf_left_surf: InputPathType | None = None,
    opt_right_area_surf_right_surf: InputPathType | None = None,
    opt_cerebellum_area_surf_cerebellum_surf: InputPathType | None = None,
    cifti: list[CiftiAverageRoiCorrelationCiftiParameters] | None = None,
    runner: Runner | None = None,
) -> CiftiAverageRoiCorrelationOutputs:
    """
    cifti-average-roi-correlation
    
    Correlate roi average with all rows then average across subjects.
    
    Averages rows for each map of the ROI(s), takes the correlation of each ROI
    average to the rest of the rows in the same file, applies the fisher small z
    transform, then averages the results across all files. ROIs are always
    treated as weighting functions, including negative values. For efficiency,
    ensure that everything that is not intended to be used is zero in the ROI
    map. If -cifti-roi is specified, -left-roi, -right-roi, -cerebellum-roi, and
    -vol-roi must not be specified. If multiple non-cifti ROI files are
    specified, they must have the same number of columns.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_out: output cifti file.
        cifti_roi: cifti file containing combined weights.
        opt_left_roi_roi_metric: weights to use for left hempsphere: the left\
            roi as a metric file.
        opt_right_roi_roi_metric: weights to use for right hempsphere: the\
            right roi as a metric file.
        opt_cerebellum_roi_roi_metric: weights to use for cerebellum surface:\
            the cerebellum roi as a metric file.
        opt_vol_roi_roi_vol: voxel weights to use: the roi volume file.
        opt_left_area_surf_left_surf: specify the left surface for vertex area\
            correction: the left surface file.
        opt_right_area_surf_right_surf: specify the right surface for vertex\
            area correction: the right surface file.
        opt_cerebellum_area_surf_cerebellum_surf: specify the cerebellum\
            surface for vertex area correction: the cerebellum surface file.
        cifti: specify an input cifti file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiAverageRoiCorrelationOutputs`).
    """
    params = cifti_average_roi_correlation_params(
        cifti_out=cifti_out,
        cifti_roi=cifti_roi,
        opt_left_roi_roi_metric=opt_left_roi_roi_metric,
        opt_right_roi_roi_metric=opt_right_roi_roi_metric,
        opt_cerebellum_roi_roi_metric=opt_cerebellum_roi_roi_metric,
        opt_vol_roi_roi_vol=opt_vol_roi_roi_vol,
        opt_left_area_surf_left_surf=opt_left_area_surf_left_surf,
        opt_right_area_surf_right_surf=opt_right_area_surf_right_surf,
        opt_cerebellum_area_surf_cerebellum_surf=opt_cerebellum_area_surf_cerebellum_surf,
        cifti=cifti,
    )
    return cifti_average_roi_correlation_execute(params, runner)


__all__ = [
    "CIFTI_AVERAGE_ROI_CORRELATION_METADATA",
    "CiftiAverageRoiCorrelationOutputs",
    "cifti_average_roi_correlation",
    "cifti_average_roi_correlation_cifti_params",
    "cifti_average_roi_correlation_cifti_roi_params",
    "cifti_average_roi_correlation_execute",
    "cifti_average_roi_correlation_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

LABEL_RESAMPLE_METADATA = Metadata(
    id="27cac022f876a408a3e9c32a66575355a7783848.boutiques",
    name="label-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


LabelResampleAreaSurfsParameters = typing.TypedDict('LabelResampleAreaSurfsParameters', {
    "@type": typing.NotRequired[typing.Literal["area_surfs"]],
    "current_area": InputPathType,
    "new_area": InputPathType,
})
LabelResampleAreaSurfsParametersTagged = typing.TypedDict('LabelResampleAreaSurfsParametersTagged', {
    "@type": typing.Literal["area_surfs"],
    "current_area": InputPathType,
    "new_area": InputPathType,
})


LabelResampleAreaMetricsParameters = typing.TypedDict('LabelResampleAreaMetricsParameters', {
    "@type": typing.NotRequired[typing.Literal["area_metrics"]],
    "current_area": InputPathType,
    "new_area": InputPathType,
})
LabelResampleAreaMetricsParametersTagged = typing.TypedDict('LabelResampleAreaMetricsParametersTagged', {
    "@type": typing.Literal["area_metrics"],
    "current_area": InputPathType,
    "new_area": InputPathType,
})


LabelResampleParameters = typing.TypedDict('LabelResampleParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/label-resample"]],
    "label_in": InputPathType,
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "method": str,
    "label_out": str,
    "area_surfs": typing.NotRequired[LabelResampleAreaSurfsParameters | None],
    "area_metrics": typing.NotRequired[LabelResampleAreaMetricsParameters | None],
    "opt_current_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_valid_roi_out_roi_out": typing.NotRequired[str | None],
    "opt_largest": bool,
    "opt_bypass_sphere_check": bool,
})
LabelResampleParametersTagged = typing.TypedDict('LabelResampleParametersTagged', {
    "@type": typing.Literal["workbench/label-resample"],
    "label_in": InputPathType,
    "current_sphere": InputPathType,
    "new_sphere": InputPathType,
    "method": str,
    "label_out": str,
    "area_surfs": typing.NotRequired[LabelResampleAreaSurfsParameters | None],
    "area_metrics": typing.NotRequired[LabelResampleAreaMetricsParameters | None],
    "opt_current_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "opt_valid_roi_out_roi_out": typing.NotRequired[str | None],
    "opt_largest": bool,
    "opt_bypass_sphere_check": bool,
})


def label_resample_area_surfs_params(
    current_area: InputPathType,
    new_area: InputPathType,
) -> LabelResampleAreaSurfsParametersTagged:
    """
    Build parameters.
    
    Args:
        current_area: a relevant anatomical surface with <current-sphere> mesh.
        new_area: a relevant anatomical surface with <new-sphere> mesh.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "area_surfs",
        "current_area": current_area,
        "new_area": new_area,
    }
    return params


def label_resample_area_surfs_cargs(
    params: LabelResampleAreaSurfsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-area-surfs")
    cargs.append(execution.input_file(params.get("current_area", None)))
    cargs.append(execution.input_file(params.get("new_area", None)))
    return cargs


def label_resample_area_metrics_params(
    current_area: InputPathType,
    new_area: InputPathType,
) -> LabelResampleAreaMetricsParametersTagged:
    """
    Build parameters.
    
    Args:
        current_area: a metric file with vertex areas for <current-sphere> mesh.
        new_area: a metric file with vertex areas for <new-sphere> mesh.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "area_metrics",
        "current_area": current_area,
        "new_area": new_area,
    }
    return params


def label_resample_area_metrics_cargs(
    params: LabelResampleAreaMetricsParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-area-metrics")
    cargs.append(execution.input_file(params.get("current_area", None)))
    cargs.append(execution.input_file(params.get("new_area", None)))
    return cargs


class LabelResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `LabelResampleParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_out: OutputPathType
    """the output label file"""
    opt_valid_roi_out_roi_out: OutputPathType | None
    """output the ROI of vertices that got data from valid source vertices: the
    output roi as a metric"""


def label_resample_params(
    label_in: InputPathType,
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    method: str,
    label_out: str,
    area_surfs: LabelResampleAreaSurfsParameters | None = None,
    area_metrics: LabelResampleAreaMetricsParameters | None = None,
    opt_current_roi_roi_metric: InputPathType | None = None,
    opt_valid_roi_out_roi_out: str | None = None,
    opt_largest: bool = False,
    opt_bypass_sphere_check: bool = False,
) -> LabelResampleParametersTagged:
    """
    Build parameters.
    
    Args:
        label_in: the label file to resample.
        current_sphere: a sphere surface with the mesh that the label file is\
            currently on.
        new_sphere: a sphere surface that is in register with <current-sphere>\
            and has the desired output mesh.
        method: the method name.
        label_out: the output label file.
        area_surfs: specify surfaces to do vertex area correction based on.
        area_metrics: specify vertex area metrics to do area correction based\
            on.
        opt_current_roi_roi_metric: use an input roi on the current mesh to\
            exclude non-data vertices: the roi, as a metric file.
        opt_valid_roi_out_roi_out: output the ROI of vertices that got data\
            from valid source vertices: the output roi as a metric.
        opt_largest: use only the label of the vertex with the largest weight.
        opt_bypass_sphere_check: ADVANCED: allow the current and new 'spheres'\
            to have arbitrary shape as long as they follow the same contour.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/label-resample",
        "label_in": label_in,
        "current_sphere": current_sphere,
        "new_sphere": new_sphere,
        "method": method,
        "label_out": label_out,
        "opt_largest": opt_largest,
        "opt_bypass_sphere_check": opt_bypass_sphere_check,
    }
    if area_surfs is not None:
        params["area_surfs"] = area_surfs
    if area_metrics is not None:
        params["area_metrics"] = area_metrics
    if opt_current_roi_roi_metric is not None:
        params["opt_current_roi_roi_metric"] = opt_current_roi_roi_metric
    if opt_valid_roi_out_roi_out is not None:
        params["opt_valid_roi_out_roi_out"] = opt_valid_roi_out_roi_out
    return params


def label_resample_cargs(
    params: LabelResampleParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-label-resample")
    cargs.append(execution.input_file(params.get("label_in", None)))
    cargs.append(execution.input_file(params.get("current_sphere", None)))
    cargs.append(execution.input_file(params.get("new_sphere", None)))
    cargs.append(params.get("method", None))
    cargs.append(params.get("label_out", None))
    if params.get("area_surfs", None) is not None:
        cargs.extend(label_resample_area_surfs_cargs(params.get("area_surfs", None), execution))
    if params.get("area_metrics", None) is not None:
        cargs.extend(label_resample_area_metrics_cargs(params.get("area_metrics", None), execution))
    if params.get("opt_current_roi_roi_metric", None) is not None:
        cargs.extend([
            "-current-roi",
            execution.input_file(params.get("opt_current_roi_roi_metric", None))
        ])
    if params.get("opt_valid_roi_out_roi_out", None) is not None:
        cargs.extend([
            "-valid-roi-out",
            params.get("opt_valid_roi_out_roi_out", None)
        ])
    if params.get("opt_largest", False):
        cargs.append("-largest")
    if params.get("opt_bypass_sphere_check", False):
        cargs.append("-bypass-sphere-check")
    return cargs


def label_resample_outputs(
    params: LabelResampleParameters,
    execution: Execution,
) -> LabelResampleOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = LabelResampleOutputs(
        root=execution.output_file("."),
        label_out=execution.output_file(params.get("label_out", None)),
        opt_valid_roi_out_roi_out=execution.output_file(params.get("opt_valid_roi_out_roi_out", None)) if (params.get("opt_valid_roi_out_roi_out") is not None) else None,
    )
    return ret


def label_resample_execute(
    params: LabelResampleParameters,
    runner: Runner | None = None,
) -> LabelResampleOutputs:
    """
    label-resample
    
    Resample a label file to a different mesh.
    
    Resamples a label file, given two spherical surfaces that are in register.
    If ADAP_BARY_AREA is used, exactly one of -area-surfs or -area-metrics must
    be specified.
    
    The ADAP_BARY_AREA method is recommended for label data, because it should
    be better at resolving vertices that are near multiple labels, or in case of
    downsampling. Midthickness surfaces are recommended for the vertex areas for
    most data.
    
    The -largest option results in nearest vertex behavior when used with
    BARYCENTRIC, as it uses the value of the source vertex that has the largest
    weight.
    
    When -largest is not specified, the vertex weights are summed according to
    which label they correspond to, and the label with the largest sum is used.
    
    The <method> argument must be one of the following:
    
    ADAP_BARY_AREA
    BARYCENTRIC
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_RESAMPLE_METADATA)
    params = execution.params(params)
    cargs = label_resample_cargs(params, execution)
    ret = label_resample_outputs(params, execution)
    execution.run(cargs)
    return ret


def label_resample(
    label_in: InputPathType,
    current_sphere: InputPathType,
    new_sphere: InputPathType,
    method: str,
    label_out: str,
    area_surfs: LabelResampleAreaSurfsParameters | None = None,
    area_metrics: LabelResampleAreaMetricsParameters | None = None,
    opt_current_roi_roi_metric: InputPathType | None = None,
    opt_valid_roi_out_roi_out: str | None = None,
    opt_largest: bool = False,
    opt_bypass_sphere_check: bool = False,
    runner: Runner | None = None,
) -> LabelResampleOutputs:
    """
    label-resample
    
    Resample a label file to a different mesh.
    
    Resamples a label file, given two spherical surfaces that are in register.
    If ADAP_BARY_AREA is used, exactly one of -area-surfs or -area-metrics must
    be specified.
    
    The ADAP_BARY_AREA method is recommended for label data, because it should
    be better at resolving vertices that are near multiple labels, or in case of
    downsampling. Midthickness surfaces are recommended for the vertex areas for
    most data.
    
    The -largest option results in nearest vertex behavior when used with
    BARYCENTRIC, as it uses the value of the source vertex that has the largest
    weight.
    
    When -largest is not specified, the vertex weights are summed according to
    which label they correspond to, and the label with the largest sum is used.
    
    The <method> argument must be one of the following:
    
    ADAP_BARY_AREA
    BARYCENTRIC
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_in: the label file to resample.
        current_sphere: a sphere surface with the mesh that the label file is\
            currently on.
        new_sphere: a sphere surface that is in register with <current-sphere>\
            and has the desired output mesh.
        method: the method name.
        label_out: the output label file.
        area_surfs: specify surfaces to do vertex area correction based on.
        area_metrics: specify vertex area metrics to do area correction based\
            on.
        opt_current_roi_roi_metric: use an input roi on the current mesh to\
            exclude non-data vertices: the roi, as a metric file.
        opt_valid_roi_out_roi_out: output the ROI of vertices that got data\
            from valid source vertices: the output roi as a metric.
        opt_largest: use only the label of the vertex with the largest weight.
        opt_bypass_sphere_check: ADVANCED: allow the current and new 'spheres'\
            to have arbitrary shape as long as they follow the same contour.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelResampleOutputs`).
    """
    params = label_resample_params(
        label_in=label_in,
        current_sphere=current_sphere,
        new_sphere=new_sphere,
        method=method,
        label_out=label_out,
        area_surfs=area_surfs,
        area_metrics=area_metrics,
        opt_current_roi_roi_metric=opt_current_roi_roi_metric,
        opt_valid_roi_out_roi_out=opt_valid_roi_out_roi_out,
        opt_largest=opt_largest,
        opt_bypass_sphere_check=opt_bypass_sphere_check,
    )
    return label_resample_execute(params, runner)


__all__ = [
    "LABEL_RESAMPLE_METADATA",
    "LabelResampleOutputs",
    "label_resample",
    "label_resample_area_metrics_params",
    "label_resample_area_surfs_params",
    "label_resample_execute",
    "label_resample_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SCENE_FILE_RELOCATE_METADATA = Metadata(
    id="ee7549becea0a121742cbf71c1a05cdf8f39b4ed.boutiques",
    name="scene-file-relocate",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SceneFileRelocateParameters = typing.TypedDict('SceneFileRelocateParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/scene-file-relocate"]],
    "input_scene": str,
    "output_scene": str,
})
SceneFileRelocateParametersTagged = typing.TypedDict('SceneFileRelocateParametersTagged', {
    "@type": typing.Literal["workbench/scene-file-relocate"],
    "input_scene": str,
    "output_scene": str,
})


class SceneFileRelocateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SceneFileRelocateParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def scene_file_relocate_params(
    input_scene: str,
    output_scene: str,
) -> SceneFileRelocateParametersTagged:
    """
    Build parameters.
    
    Args:
        input_scene: the scene file to use.
        output_scene: output - the new scene file to create.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/scene-file-relocate",
        "input_scene": input_scene,
        "output_scene": output_scene,
    }
    return params


def scene_file_relocate_cargs(
    params: SceneFileRelocateParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-scene-file-relocate")
    cargs.append(params.get("input_scene", None))
    cargs.append(params.get("output_scene", None))
    return cargs


def scene_file_relocate_outputs(
    params: SceneFileRelocateParameters,
    execution: Execution,
) -> SceneFileRelocateOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SceneFileRelocateOutputs(
        root=execution.output_file("."),
    )
    return ret


def scene_file_relocate_execute(
    params: SceneFileRelocateParameters,
    runner: Runner | None = None,
) -> SceneFileRelocateOutputs:
    """
    scene-file-relocate
    
    Recreate scene file in new location.
    
    Scene files contain internal relative paths, such that moving or copying a
    scene file will cause it to lose track of the files it refers to. This
    command makes a modified copy of the scene file, changing the relative paths
    to refer to the new relative locations of the files.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SceneFileRelocateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SCENE_FILE_RELOCATE_METADATA)
    params = execution.params(params)
    cargs = scene_file_relocate_cargs(params, execution)
    ret = scene_file_relocate_outputs(params, execution)
    execution.run(cargs)
    return ret


def scene_file_relocate(
    input_scene: str,
    output_scene: str,
    runner: Runner | None = None,
) -> SceneFileRelocateOutputs:
    """
    scene-file-relocate
    
    Recreate scene file in new location.
    
    Scene files contain internal relative paths, such that moving or copying a
    scene file will cause it to lose track of the files it refers to. This
    command makes a modified copy of the scene file, changing the relative paths
    to refer to the new relative locations of the files.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        input_scene: the scene file to use.
        output_scene: output - the new scene file to create.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SceneFileRelocateOutputs`).
    """
    params = scene_file_relocate_params(
        input_scene=input_scene,
        output_scene=output_scene,
    )
    return scene_file_relocate_execute(params, runner)


__all__ = [
    "SCENE_FILE_RELOCATE_METADATA",
    "SceneFileRelocateOutputs",
    "scene_file_relocate",
    "scene_file_relocate_execute",
    "scene_file_relocate_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_EXTREMA_METADATA = Metadata(
    id="35ad3fc8fea052df6bc06cbe31e38898ec741593.boutiques",
    name="volume-extrema",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeExtremaPresmoothParameters = typing.TypedDict('VolumeExtremaPresmoothParameters', {
    "@type": typing.NotRequired[typing.Literal["presmooth"]],
    "kernel": float,
    "opt_fwhm": bool,
})
VolumeExtremaPresmoothParametersTagged = typing.TypedDict('VolumeExtremaPresmoothParametersTagged', {
    "@type": typing.Literal["presmooth"],
    "kernel": float,
    "opt_fwhm": bool,
})


VolumeExtremaThresholdParameters = typing.TypedDict('VolumeExtremaThresholdParameters', {
    "@type": typing.NotRequired[typing.Literal["threshold"]],
    "low": float,
    "high": float,
})
VolumeExtremaThresholdParametersTagged = typing.TypedDict('VolumeExtremaThresholdParametersTagged', {
    "@type": typing.Literal["threshold"],
    "low": float,
    "high": float,
})


VolumeExtremaParameters = typing.TypedDict('VolumeExtremaParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-extrema"]],
    "volume_in": InputPathType,
    "distance": float,
    "volume_out": str,
    "presmooth": typing.NotRequired[VolumeExtremaPresmoothParameters | None],
    "opt_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "threshold": typing.NotRequired[VolumeExtremaThresholdParameters | None],
    "opt_sum_subvols": bool,
    "opt_consolidate_mode": bool,
    "opt_only_maxima": bool,
    "opt_only_minima": bool,
    "opt_subvolume_subvolume": typing.NotRequired[str | None],
})
VolumeExtremaParametersTagged = typing.TypedDict('VolumeExtremaParametersTagged', {
    "@type": typing.Literal["workbench/volume-extrema"],
    "volume_in": InputPathType,
    "distance": float,
    "volume_out": str,
    "presmooth": typing.NotRequired[VolumeExtremaPresmoothParameters | None],
    "opt_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "threshold": typing.NotRequired[VolumeExtremaThresholdParameters | None],
    "opt_sum_subvols": bool,
    "opt_consolidate_mode": bool,
    "opt_only_maxima": bool,
    "opt_only_minima": bool,
    "opt_subvolume_subvolume": typing.NotRequired[str | None],
})


def volume_extrema_presmooth_params(
    kernel: float,
    opt_fwhm: bool = False,
) -> VolumeExtremaPresmoothParametersTagged:
    """
    Build parameters.
    
    Args:
        kernel: the size of the gaussian smoothing kernel in mm, as sigma by\
            default.
        opt_fwhm: kernel size is FWHM, not sigma.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "presmooth",
        "kernel": kernel,
        "opt_fwhm": opt_fwhm,
    }
    return params


def volume_extrema_presmooth_cargs(
    params: VolumeExtremaPresmoothParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-presmooth")
    cargs.append(str(params.get("kernel", None)))
    if params.get("opt_fwhm", False):
        cargs.append("-fwhm")
    return cargs


def volume_extrema_threshold_params(
    low: float,
    high: float,
) -> VolumeExtremaThresholdParametersTagged:
    """
    Build parameters.
    
    Args:
        low: the largest value to consider for being a minimum.
        high: the smallest value to consider for being a maximum.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "threshold",
        "low": low,
        "high": high,
    }
    return params


def volume_extrema_threshold_cargs(
    params: VolumeExtremaThresholdParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-threshold")
    cargs.append(str(params.get("low", None)))
    cargs.append(str(params.get("high", None)))
    return cargs


class VolumeExtremaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeExtremaParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output extrema volume"""


def volume_extrema_params(
    volume_in: InputPathType,
    distance: float,
    volume_out: str,
    presmooth: VolumeExtremaPresmoothParameters | None = None,
    opt_roi_roi_volume: InputPathType | None = None,
    threshold: VolumeExtremaThresholdParameters | None = None,
    opt_sum_subvols: bool = False,
    opt_consolidate_mode: bool = False,
    opt_only_maxima: bool = False,
    opt_only_minima: bool = False,
    opt_subvolume_subvolume: str | None = None,
) -> VolumeExtremaParametersTagged:
    """
    Build parameters.
    
    Args:
        volume_in: volume file to find the extrema of.
        distance: the minimum distance between identified extrema of the same\
            type.
        volume_out: the output extrema volume.
        presmooth: smooth the volume before finding extrema.
        opt_roi_roi_volume: ignore values outside the selected area: the area\
            to find extrema in.
        threshold: ignore small extrema.
        opt_sum_subvols: output the sum of the extrema subvolumes instead of\
            each subvolume separately.
        opt_consolidate_mode: use consolidation of local minima instead of a\
            large neighborhood.
        opt_only_maxima: only find the maxima.
        opt_only_minima: only find the minima.
        opt_subvolume_subvolume: select a single subvolume to find extrema in:\
            the subvolume number or name.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-extrema",
        "volume_in": volume_in,
        "distance": distance,
        "volume_out": volume_out,
        "opt_sum_subvols": opt_sum_subvols,
        "opt_consolidate_mode": opt_consolidate_mode,
        "opt_only_maxima": opt_only_maxima,
        "opt_only_minima": opt_only_minima,
    }
    if presmooth is not None:
        params["presmooth"] = presmooth
    if opt_roi_roi_volume is not None:
        params["opt_roi_roi_volume"] = opt_roi_roi_volume
    if threshold is not None:
        params["threshold"] = threshold
    if opt_subvolume_subvolume is not None:
        params["opt_subvolume_subvolume"] = opt_subvolume_subvolume
    return params


def volume_extrema_cargs(
    params: VolumeExtremaParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-extrema")
    cargs.append(execution.input_file(params.get("volume_in", None)))
    cargs.append(str(params.get("distance", None)))
    cargs.append(params.get("volume_out", None))
    if params.get("presmooth", None) is not None:
        cargs.extend(volume_extrema_presmooth_cargs(params.get("presmooth", None), execution))
    if params.get("opt_roi_roi_volume", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roi_volume", None))
        ])
    if params.get("threshold", None) is not None:
        cargs.extend(volume_extrema_threshold_cargs(params.get("threshold", None), execution))
    if params.get("opt_sum_subvols", False):
        cargs.append("-sum-subvols")
    if params.get("opt_consolidate_mode", False):
        cargs.append("-consolidate-mode")
    if params.get("opt_only_maxima", False):
        cargs.append("-only-maxima")
    if params.get("opt_only_minima", False):
        cargs.append("-only-minima")
    if params.get("opt_subvolume_subvolume", None) is not None:
        cargs.extend([
            "-subvolume",
            params.get("opt_subvolume_subvolume", None)
        ])
    return cargs


def volume_extrema_outputs(
    params: VolumeExtremaParameters,
    execution: Execution,
) -> VolumeExtremaOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeExtremaOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_extrema_execute(
    params: VolumeExtremaParameters,
    runner: Runner | None = None,
) -> VolumeExtremaOutputs:
    """
    volume-extrema
    
    Find extrema in a volume file.
    
    Finds extrema in a volume file, such that no two extrema of the same type
    are within <distance> of each other. The extrema are labeled as -1 for
    minima, 1 for maxima, 0 otherwise. If -only-maxima or -only-minima is
    specified, then it will ignore extrema not of the specified type. These
    options are mutually exclusive.
    
    If -sum-subvols is specified, these extrema subvolumes are summed, and the
    output has a single subvolume with this result.
    
    By default, a datapoint is an extrema only if it is more extreme than every
    other datapoint that is within <distance> from it. If -consolidate-mode is
    used, it instead starts by finding all datapoints that are more extreme than
    their immediate neighbors, then while there are any extrema within
    <distance> of each other, take the two extrema closest to each other and
    merge them into one by a weighted average based on how many original extrema
    have been merged into each.
    
    By default, all input subvolumes are used with no smoothing, use -subvolume
    to specify a single subvolume to use, and -presmooth to smooth the input
    before finding the extrema.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeExtremaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_EXTREMA_METADATA)
    params = execution.params(params)
    cargs = volume_extrema_cargs(params, execution)
    ret = volume_extrema_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_extrema(
    volume_in: InputPathType,
    distance: float,
    volume_out: str,
    presmooth: VolumeExtremaPresmoothParameters | None = None,
    opt_roi_roi_volume: InputPathType | None = None,
    threshold: VolumeExtremaThresholdParameters | None = None,
    opt_sum_subvols: bool = False,
    opt_consolidate_mode: bool = False,
    opt_only_maxima: bool = False,
    opt_only_minima: bool = False,
    opt_subvolume_subvolume: str | None = None,
    runner: Runner | None = None,
) -> VolumeExtremaOutputs:
    """
    volume-extrema
    
    Find extrema in a volume file.
    
    Finds extrema in a volume file, such that no two extrema of the same type
    are within <distance> of each other. The extrema are labeled as -1 for
    minima, 1 for maxima, 0 otherwise. If -only-maxima or -only-minima is
    specified, then it will ignore extrema not of the specified type. These
    options are mutually exclusive.
    
    If -sum-subvols is specified, these extrema subvolumes are summed, and the
    output has a single subvolume with this result.
    
    By default, a datapoint is an extrema only if it is more extreme than every
    other datapoint that is within <distance> from it. If -consolidate-mode is
    used, it instead starts by finding all datapoints that are more extreme than
    their immediate neighbors, then while there are any extrema within
    <distance> of each other, take the two extrema closest to each other and
    merge them into one by a weighted average based on how many original extrema
    have been merged into each.
    
    By default, all input subvolumes are used with no smoothing, use -subvolume
    to specify a single subvolume to use, and -presmooth to smooth the input
    before finding the extrema.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: volume file to find the extrema of.
        distance: the minimum distance between identified extrema of the same\
            type.
        volume_out: the output extrema volume.
        presmooth: smooth the volume before finding extrema.
        opt_roi_roi_volume: ignore values outside the selected area: the area\
            to find extrema in.
        threshold: ignore small extrema.
        opt_sum_subvols: output the sum of the extrema subvolumes instead of\
            each subvolume separately.
        opt_consolidate_mode: use consolidation of local minima instead of a\
            large neighborhood.
        opt_only_maxima: only find the maxima.
        opt_only_minima: only find the minima.
        opt_subvolume_subvolume: select a single subvolume to find extrema in:\
            the subvolume number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeExtremaOutputs`).
    """
    params = volume_extrema_params(
        volume_in=volume_in,
        distance=distance,
        volume_out=volume_out,
        presmooth=presmooth,
        opt_roi_roi_volume=opt_roi_roi_volume,
        threshold=threshold,
        opt_sum_subvols=opt_sum_subvols,
        opt_consolidate_mode=opt_consolidate_mode,
        opt_only_maxima=opt_only_maxima,
        opt_only_minima=opt_only_minima,
        opt_subvolume_subvolume=opt_subvolume_subvolume,
    )
    return volume_extrema_execute(params, runner)


__all__ = [
    "VOLUME_EXTREMA_METADATA",
    "VolumeExtremaOutputs",
    "volume_extrema",
    "volume_extrema_execute",
    "volume_extrema_params",
    "volume_extrema_presmooth_params",
    "volume_extrema_threshold_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_ROIS_FROM_EXTREMA_METADATA = Metadata(
    id="fff039813d35484e8dfeace02e6d5c8748973490.boutiques",
    name="volume-rois-from-extrema",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeRoisFromExtremaParameters = typing.TypedDict('VolumeRoisFromExtremaParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-rois-from-extrema"]],
    "volume_in": InputPathType,
    "limit": float,
    "volume_out": str,
    "opt_gaussian_sigma": typing.NotRequired[float | None],
    "opt_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "opt_overlap_logic_method": typing.NotRequired[str | None],
    "opt_subvolume_subvol": typing.NotRequired[str | None],
})
VolumeRoisFromExtremaParametersTagged = typing.TypedDict('VolumeRoisFromExtremaParametersTagged', {
    "@type": typing.Literal["workbench/volume-rois-from-extrema"],
    "volume_in": InputPathType,
    "limit": float,
    "volume_out": str,
    "opt_gaussian_sigma": typing.NotRequired[float | None],
    "opt_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "opt_overlap_logic_method": typing.NotRequired[str | None],
    "opt_subvolume_subvol": typing.NotRequired[str | None],
})


class VolumeRoisFromExtremaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeRoisFromExtremaParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_rois_from_extrema_params(
    volume_in: InputPathType,
    limit: float,
    volume_out: str,
    opt_gaussian_sigma: float | None = None,
    opt_roi_roi_volume: InputPathType | None = None,
    opt_overlap_logic_method: str | None = None,
    opt_subvolume_subvol: str | None = None,
) -> VolumeRoisFromExtremaParametersTagged:
    """
    Build parameters.
    
    Args:
        volume_in: the input volume.
        limit: distance limit from voxel center, in mm.
        volume_out: the output volume.
        opt_gaussian_sigma: generate a gaussian kernel instead of a flat ROI:\
            the sigma for the gaussian kernel, in mm.
        opt_roi_roi_volume: select a region of interest to use: the region to\
            use.
        opt_overlap_logic_method: how to handle overlapping ROIs, default\
            ALLOW: the method of resolving overlaps.
        opt_subvolume_subvol: select a single subvolume to take the gradient\
            of: the subvolume number or name.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-rois-from-extrema",
        "volume_in": volume_in,
        "limit": limit,
        "volume_out": volume_out,
    }
    if opt_gaussian_sigma is not None:
        params["opt_gaussian_sigma"] = opt_gaussian_sigma
    if opt_roi_roi_volume is not None:
        params["opt_roi_roi_volume"] = opt_roi_roi_volume
    if opt_overlap_logic_method is not None:
        params["opt_overlap_logic_method"] = opt_overlap_logic_method
    if opt_subvolume_subvol is not None:
        params["opt_subvolume_subvol"] = opt_subvolume_subvol
    return params


def volume_rois_from_extrema_cargs(
    params: VolumeRoisFromExtremaParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-rois-from-extrema")
    cargs.append(execution.input_file(params.get("volume_in", None)))
    cargs.append(str(params.get("limit", None)))
    cargs.append(params.get("volume_out", None))
    if params.get("opt_gaussian_sigma", None) is not None:
        cargs.extend([
            "-gaussian",
            str(params.get("opt_gaussian_sigma", None))
        ])
    if params.get("opt_roi_roi_volume", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roi_volume", None))
        ])
    if params.get("opt_overlap_logic_method", None) is not None:
        cargs.extend([
            "-overlap-logic",
            params.get("opt_overlap_logic_method", None)
        ])
    if params.get("opt_subvolume_subvol", None) is not None:
        cargs.extend([
            "-subvolume",
            params.get("opt_subvolume_subvol", None)
        ])
    return cargs


def volume_rois_from_extrema_outputs(
    params: VolumeRoisFromExtremaParameters,
    execution: Execution,
) -> VolumeRoisFromExtremaOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeRoisFromExtremaOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_rois_from_extrema_execute(
    params: VolumeRoisFromExtremaParameters,
    runner: Runner | None = None,
) -> VolumeRoisFromExtremaOutputs:
    """
    volume-rois-from-extrema
    
    Create volume roi maps from extrema maps.
    
    For each nonzero value in each map, make a map with an ROI around that
    location. If the -gaussian option is specified, then normalized gaussian
    kernels are output instead of ROIs. The <method> argument to -overlap-logic
    must be one of ALLOW, CLOSEST, or EXCLUDE. ALLOW is the default, and means
    that ROIs are treated independently and may overlap. CLOSEST means that ROIs
    may not overlap, and that no ROI contains vertices that are closer to a
    different seed vertex. EXCLUDE means that ROIs may not overlap, and that any
    vertex within range of more than one ROI does not belong to any ROI.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeRoisFromExtremaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_ROIS_FROM_EXTREMA_METADATA)
    params = execution.params(params)
    cargs = volume_rois_from_extrema_cargs(params, execution)
    ret = volume_rois_from_extrema_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_rois_from_extrema(
    volume_in: InputPathType,
    limit: float,
    volume_out: str,
    opt_gaussian_sigma: float | None = None,
    opt_roi_roi_volume: InputPathType | None = None,
    opt_overlap_logic_method: str | None = None,
    opt_subvolume_subvol: str | None = None,
    runner: Runner | None = None,
) -> VolumeRoisFromExtremaOutputs:
    """
    volume-rois-from-extrema
    
    Create volume roi maps from extrema maps.
    
    For each nonzero value in each map, make a map with an ROI around that
    location. If the -gaussian option is specified, then normalized gaussian
    kernels are output instead of ROIs. The <method> argument to -overlap-logic
    must be one of ALLOW, CLOSEST, or EXCLUDE. ALLOW is the default, and means
    that ROIs are treated independently and may overlap. CLOSEST means that ROIs
    may not overlap, and that no ROI contains vertices that are closer to a
    different seed vertex. EXCLUDE means that ROIs may not overlap, and that any
    vertex within range of more than one ROI does not belong to any ROI.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: the input volume.
        limit: distance limit from voxel center, in mm.
        volume_out: the output volume.
        opt_gaussian_sigma: generate a gaussian kernel instead of a flat ROI:\
            the sigma for the gaussian kernel, in mm.
        opt_roi_roi_volume: select a region of interest to use: the region to\
            use.
        opt_overlap_logic_method: how to handle overlapping ROIs, default\
            ALLOW: the method of resolving overlaps.
        opt_subvolume_subvol: select a single subvolume to take the gradient\
            of: the subvolume number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeRoisFromExtremaOutputs`).
    """
    params = volume_rois_from_extrema_params(
        volume_in=volume_in,
        limit=limit,
        volume_out=volume_out,
        opt_gaussian_sigma=opt_gaussian_sigma,
        opt_roi_roi_volume=opt_roi_roi_volume,
        opt_overlap_logic_method=opt_overlap_logic_method,
        opt_subvolume_subvol=opt_subvolume_subvol,
    )
    return volume_rois_from_extrema_execute(params, runner)


__all__ = [
    "VOLUME_ROIS_FROM_EXTREMA_METADATA",
    "VolumeRoisFromExtremaOutputs",
    "volume_rois_from_extrema",
    "volume_rois_from_extrema_execute",
    "volume_rois_from_extrema_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_MERGE_METADATA = Metadata(
    id="fc657fa415442ff85ef1c87698be56c45aad5857.boutiques",
    name="metric-merge",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricMergeUpToParameters = typing.TypedDict('MetricMergeUpToParameters', {
    "@type": typing.NotRequired[typing.Literal["up_to"]],
    "last_column": str,
    "opt_reverse": bool,
})
MetricMergeUpToParametersTagged = typing.TypedDict('MetricMergeUpToParametersTagged', {
    "@type": typing.Literal["up_to"],
    "last_column": str,
    "opt_reverse": bool,
})


MetricMergeColumnParameters = typing.TypedDict('MetricMergeColumnParameters', {
    "@type": typing.NotRequired[typing.Literal["column"]],
    "column": str,
    "up_to": typing.NotRequired[MetricMergeUpToParameters | None],
})
MetricMergeColumnParametersTagged = typing.TypedDict('MetricMergeColumnParametersTagged', {
    "@type": typing.Literal["column"],
    "column": str,
    "up_to": typing.NotRequired[MetricMergeUpToParameters | None],
})


MetricMergeMetricParameters = typing.TypedDict('MetricMergeMetricParameters', {
    "@type": typing.NotRequired[typing.Literal["metric"]],
    "metric_in": InputPathType,
    "column": typing.NotRequired[list[MetricMergeColumnParameters] | None],
})
MetricMergeMetricParametersTagged = typing.TypedDict('MetricMergeMetricParametersTagged', {
    "@type": typing.Literal["metric"],
    "metric_in": InputPathType,
    "column": typing.NotRequired[list[MetricMergeColumnParameters] | None],
})


MetricMergeParameters = typing.TypedDict('MetricMergeParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-merge"]],
    "metric_out": str,
    "metric": typing.NotRequired[list[MetricMergeMetricParameters] | None],
})
MetricMergeParametersTagged = typing.TypedDict('MetricMergeParametersTagged', {
    "@type": typing.Literal["workbench/metric-merge"],
    "metric_out": str,
    "metric": typing.NotRequired[list[MetricMergeMetricParameters] | None],
})


def metric_merge_up_to_params(
    last_column: str,
    opt_reverse: bool = False,
) -> MetricMergeUpToParametersTagged:
    """
    Build parameters.
    
    Args:
        last_column: the number or name of the last column to include.
        opt_reverse: use the range in reverse order.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "up_to",
        "last_column": last_column,
        "opt_reverse": opt_reverse,
    }
    return params


def metric_merge_up_to_cargs(
    params: MetricMergeUpToParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-up-to")
    cargs.append(params.get("last_column", None))
    if params.get("opt_reverse", False):
        cargs.append("-reverse")
    return cargs


def metric_merge_column_params(
    column: str,
    up_to: MetricMergeUpToParameters | None = None,
) -> MetricMergeColumnParametersTagged:
    """
    Build parameters.
    
    Args:
        column: the column number or name.
        up_to: use an inclusive range of columns.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "column",
        "column": column,
    }
    if up_to is not None:
        params["up_to"] = up_to
    return params


def metric_merge_column_cargs(
    params: MetricMergeColumnParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-column")
    cargs.append(params.get("column", None))
    if params.get("up_to", None) is not None:
        cargs.extend(metric_merge_up_to_cargs(params.get("up_to", None), execution))
    return cargs


def metric_merge_metric_params(
    metric_in: InputPathType,
    column: list[MetricMergeColumnParameters] | None = None,
) -> MetricMergeMetricParametersTagged:
    """
    Build parameters.
    
    Args:
        metric_in: a metric file to use columns from.
        column: select a single column to use.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "metric",
        "metric_in": metric_in,
    }
    if column is not None:
        params["column"] = column
    return params


def metric_merge_metric_cargs(
    params: MetricMergeMetricParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-metric")
    cargs.append(execution.input_file(params.get("metric_in", None)))
    if params.get("column", None) is not None:
        cargs.extend([a for c in [metric_merge_column_cargs(s, execution) for s in params.get("column", None)] for a in c])
    return cargs


class MetricMergeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricMergeParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_merge_params(
    metric_out: str,
    metric: list[MetricMergeMetricParameters] | None = None,
) -> MetricMergeParametersTagged:
    """
    Build parameters.
    
    Args:
        metric_out: the output metric.
        metric: specify an input metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-merge",
        "metric_out": metric_out,
    }
    if metric is not None:
        params["metric"] = metric
    return params


def metric_merge_cargs(
    params: MetricMergeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-merge")
    cargs.append(params.get("metric_out", None))
    if params.get("metric", None) is not None:
        cargs.extend([a for c in [metric_merge_metric_cargs(s, execution) for s in params.get("metric", None)] for a in c])
    return cargs


def metric_merge_outputs(
    params: MetricMergeParameters,
    execution: Execution,
) -> MetricMergeOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricMergeOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def metric_merge_execute(
    params: MetricMergeParameters,
    runner: Runner | None = None,
) -> MetricMergeOutputs:
    """
    metric-merge
    
    Merge metric files into a new file.
    
    Takes one or more metric files and constructs a new metric file by
    concatenating columns from them. The input metric files must have the same
    number of vertices and same structure.
    
    Example: wb_command -metric-merge out.func.gii -metric first.func.gii
    -column 1 -metric second.func.gii
    
    This example would take the first column from first.func.gii, followed by
    all columns from second.func.gii, and write these columns to out.func.gii.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricMergeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_MERGE_METADATA)
    params = execution.params(params)
    cargs = metric_merge_cargs(params, execution)
    ret = metric_merge_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_merge(
    metric_out: str,
    metric: list[MetricMergeMetricParameters] | None = None,
    runner: Runner | None = None,
) -> MetricMergeOutputs:
    """
    metric-merge
    
    Merge metric files into a new file.
    
    Takes one or more metric files and constructs a new metric file by
    concatenating columns from them. The input metric files must have the same
    number of vertices and same structure.
    
    Example: wb_command -metric-merge out.func.gii -metric first.func.gii
    -column 1 -metric second.func.gii
    
    This example would take the first column from first.func.gii, followed by
    all columns from second.func.gii, and write these columns to out.func.gii.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        metric_out: the output metric.
        metric: specify an input metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricMergeOutputs`).
    """
    params = metric_merge_params(
        metric_out=metric_out,
        metric=metric,
    )
    return metric_merge_execute(params, runner)


__all__ = [
    "METRIC_MERGE_METADATA",
    "MetricMergeOutputs",
    "metric_merge",
    "metric_merge_column_params",
    "metric_merge_execute",
    "metric_merge_metric_params",
    "metric_merge_params",
    "metric_merge_up_to_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

FILE_INFORMATION_METADATA = Metadata(
    id="e3813c3642722f68debee824d157b7d426ca7f32.boutiques",
    name="file-information",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


FileInformationOnlyMetadataParameters = typing.TypedDict('FileInformationOnlyMetadataParameters', {
    "@type": typing.NotRequired[typing.Literal["only_metadata"]],
    "opt_key_key": typing.NotRequired[str | None],
})
FileInformationOnlyMetadataParametersTagged = typing.TypedDict('FileInformationOnlyMetadataParametersTagged', {
    "@type": typing.Literal["only_metadata"],
    "opt_key_key": typing.NotRequired[str | None],
})


FileInformationParameters = typing.TypedDict('FileInformationParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/file-information"]],
    "data_file": str,
    "opt_no_map_info": bool,
    "opt_only_step_interval": bool,
    "opt_only_number_of_maps": bool,
    "opt_only_map_names": bool,
    "only_metadata": typing.NotRequired[FileInformationOnlyMetadataParameters | None],
    "opt_only_cifti_xml": bool,
    "opt_czi": bool,
    "opt_czi_all_sub_blocks": bool,
    "opt_czi_xml": bool,
})
FileInformationParametersTagged = typing.TypedDict('FileInformationParametersTagged', {
    "@type": typing.Literal["workbench/file-information"],
    "data_file": str,
    "opt_no_map_info": bool,
    "opt_only_step_interval": bool,
    "opt_only_number_of_maps": bool,
    "opt_only_map_names": bool,
    "only_metadata": typing.NotRequired[FileInformationOnlyMetadataParameters | None],
    "opt_only_cifti_xml": bool,
    "opt_czi": bool,
    "opt_czi_all_sub_blocks": bool,
    "opt_czi_xml": bool,
})


def file_information_only_metadata_params(
    opt_key_key: str | None = None,
) -> FileInformationOnlyMetadataParametersTagged:
    """
    Build parameters.
    
    Args:
        opt_key_key: only print the metadata for one key, with no formatting:\
            the metadata key.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "only_metadata",
    }
    if opt_key_key is not None:
        params["opt_key_key"] = opt_key_key
    return params


def file_information_only_metadata_cargs(
    params: FileInformationOnlyMetadataParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-only-metadata")
    if params.get("opt_key_key", None) is not None:
        cargs.extend([
            "-key",
            params.get("opt_key_key", None)
        ])
    return cargs


class FileInformationOutputs(typing.NamedTuple):
    """
    Output object returned when calling `FileInformationParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def file_information_params(
    data_file: str,
    opt_no_map_info: bool = False,
    opt_only_step_interval: bool = False,
    opt_only_number_of_maps: bool = False,
    opt_only_map_names: bool = False,
    only_metadata: FileInformationOnlyMetadataParameters | None = None,
    opt_only_cifti_xml: bool = False,
    opt_czi: bool = False,
    opt_czi_all_sub_blocks: bool = False,
    opt_czi_xml: bool = False,
) -> FileInformationParametersTagged:
    """
    Build parameters.
    
    Args:
        data_file: data file.
        opt_no_map_info: do not show map information for files that support\
            maps.
        opt_only_step_interval: suppress normal output, print the interval\
            between maps.
        opt_only_number_of_maps: suppress normal output, print the number of\
            maps.
        opt_only_map_names: suppress normal output, print the names of all maps.
        only_metadata: suppress normal output, print file metadata.
        opt_only_cifti_xml: suppress normal output, print the cifti xml if the\
            file type has it.
        opt_czi: For a CZI file, show information from the libCZI Info Command\
            instead of the Workbench CZI File.
        opt_czi_all_sub_blocks: show all sub-blocks in CZI file (may produce\
            long output).
        opt_czi_xml: show XML from CZI file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/file-information",
        "data_file": data_file,
        "opt_no_map_info": opt_no_map_info,
        "opt_only_step_interval": opt_only_step_interval,
        "opt_only_number_of_maps": opt_only_number_of_maps,
        "opt_only_map_names": opt_only_map_names,
        "opt_only_cifti_xml": opt_only_cifti_xml,
        "opt_czi": opt_czi,
        "opt_czi_all_sub_blocks": opt_czi_all_sub_blocks,
        "opt_czi_xml": opt_czi_xml,
    }
    if only_metadata is not None:
        params["only_metadata"] = only_metadata
    return params


def file_information_cargs(
    params: FileInformationParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-file-information")
    cargs.append(params.get("data_file", None))
    if params.get("opt_no_map_info", False):
        cargs.append("-no-map-info")
    if params.get("opt_only_step_interval", False):
        cargs.append("-only-step-interval")
    if params.get("opt_only_number_of_maps", False):
        cargs.append("-only-number-of-maps")
    if params.get("opt_only_map_names", False):
        cargs.append("-only-map-names")
    if params.get("only_metadata", None) is not None:
        cargs.extend(file_information_only_metadata_cargs(params.get("only_metadata", None), execution))
    if params.get("opt_only_cifti_xml", False):
        cargs.append("-only-cifti-xml")
    if params.get("opt_czi", False):
        cargs.append("-czi")
    if params.get("opt_czi_all_sub_blocks", False):
        cargs.append("-czi-all-sub-blocks")
    if params.get("opt_czi_xml", False):
        cargs.append("-czi-xml")
    return cargs


def file_information_outputs(
    params: FileInformationParameters,
    execution: Execution,
) -> FileInformationOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = FileInformationOutputs(
        root=execution.output_file("."),
    )
    return ret


def file_information_execute(
    params: FileInformationParameters,
    runner: Runner | None = None,
) -> FileInformationOutputs:
    """
    file-information
    
    List information about a file's content.
    
    List information about the content of a data file. Only one -only option may
    be specified. The information listed when no -only option is present is
    dependent upon the type of data file.
    
    Library paths:
    /usr/lib/x86_64-linux-gnu/qt5/plugins
    
    /mnt/c/Users/floru/Projects/cmi/nopype/extraction/workbench/source/build/CommandLine
    
    
    File and extensions for reading and writing:
    Annotation: wb_annot
    Annotation Text Substitution: wb_annsub.csv
    Border: border, wb_border
    CIFTI - Dense: dconn.nii
    CIFTI - Dense Label: dlabel.nii
    CIFTI - Dense Parcel: dpconn.nii
    CIFTI - Dense Scalar: dscalar.nii
    CIFTI - Dense Data Series: dtseries.nii
    CIFTI - Fiber Orientations TEMPORARY: fiberTEMP.nii
    CIFTI - Fiber Trajectory TEMPORARY: trajTEMP.wbsparse
    CIFTI - Parcel: pconn.nii
    CIFTI - Parcel Dense: pdconn.nii
    CIFTI - Parcel Label: plabel.nii
    CIFTI - Parcel Scalar: pscalar.nii
    CIFTI - Parcel Series: ptseries.nii
    CIFTI - Scalar Data Series: sdseries.nii
    CZI Image: czi
    Foci: foci, wb_foci
    Histology Slices: metaczi, meta-image
    Image Read: bmp, gif, jpeg, jpg, png, ppm
    Write: bmp, jpeg, jpg, png, ppm
    Label: label.gii
    Metric: func.gii, shape.gii
    Palette: palette, wb_palette
    RGBA: rgba.gii
    Samples: wb_samples
    Scene: scene, wb_scene
    Specification: spec, wb_spec
    Surface: surf.gii
    Volume: nii, nii.gz
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FileInformationOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FILE_INFORMATION_METADATA)
    params = execution.params(params)
    cargs = file_information_cargs(params, execution)
    ret = file_information_outputs(params, execution)
    execution.run(cargs)
    return ret


def file_information(
    data_file: str,
    opt_no_map_info: bool = False,
    opt_only_step_interval: bool = False,
    opt_only_number_of_maps: bool = False,
    opt_only_map_names: bool = False,
    only_metadata: FileInformationOnlyMetadataParameters | None = None,
    opt_only_cifti_xml: bool = False,
    opt_czi: bool = False,
    opt_czi_all_sub_blocks: bool = False,
    opt_czi_xml: bool = False,
    runner: Runner | None = None,
) -> FileInformationOutputs:
    """
    file-information
    
    List information about a file's content.
    
    List information about the content of a data file. Only one -only option may
    be specified. The information listed when no -only option is present is
    dependent upon the type of data file.
    
    Library paths:
    /usr/lib/x86_64-linux-gnu/qt5/plugins
    
    /mnt/c/Users/floru/Projects/cmi/nopype/extraction/workbench/source/build/CommandLine
    
    
    File and extensions for reading and writing:
    Annotation: wb_annot
    Annotation Text Substitution: wb_annsub.csv
    Border: border, wb_border
    CIFTI - Dense: dconn.nii
    CIFTI - Dense Label: dlabel.nii
    CIFTI - Dense Parcel: dpconn.nii
    CIFTI - Dense Scalar: dscalar.nii
    CIFTI - Dense Data Series: dtseries.nii
    CIFTI - Fiber Orientations TEMPORARY: fiberTEMP.nii
    CIFTI - Fiber Trajectory TEMPORARY: trajTEMP.wbsparse
    CIFTI - Parcel: pconn.nii
    CIFTI - Parcel Dense: pdconn.nii
    CIFTI - Parcel Label: plabel.nii
    CIFTI - Parcel Scalar: pscalar.nii
    CIFTI - Parcel Series: ptseries.nii
    CIFTI - Scalar Data Series: sdseries.nii
    CZI Image: czi
    Foci: foci, wb_foci
    Histology Slices: metaczi, meta-image
    Image Read: bmp, gif, jpeg, jpg, png, ppm
    Write: bmp, jpeg, jpg, png, ppm
    Label: label.gii
    Metric: func.gii, shape.gii
    Palette: palette, wb_palette
    RGBA: rgba.gii
    Samples: wb_samples
    Scene: scene, wb_scene
    Specification: spec, wb_spec
    Surface: surf.gii
    Volume: nii, nii.gz
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        data_file: data file.
        opt_no_map_info: do not show map information for files that support\
            maps.
        opt_only_step_interval: suppress normal output, print the interval\
            between maps.
        opt_only_number_of_maps: suppress normal output, print the number of\
            maps.
        opt_only_map_names: suppress normal output, print the names of all maps.
        only_metadata: suppress normal output, print file metadata.
        opt_only_cifti_xml: suppress normal output, print the cifti xml if the\
            file type has it.
        opt_czi: For a CZI file, show information from the libCZI Info Command\
            instead of the Workbench CZI File.
        opt_czi_all_sub_blocks: show all sub-blocks in CZI file (may produce\
            long output).
        opt_czi_xml: show XML from CZI file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FileInformationOutputs`).
    """
    params = file_information_params(
        data_file=data_file,
        opt_no_map_info=opt_no_map_info,
        opt_only_step_interval=opt_only_step_interval,
        opt_only_number_of_maps=opt_only_number_of_maps,
        opt_only_map_names=opt_only_map_names,
        only_metadata=only_metadata,
        opt_only_cifti_xml=opt_only_cifti_xml,
        opt_czi=opt_czi,
        opt_czi_all_sub_blocks=opt_czi_all_sub_blocks,
        opt_czi_xml=opt_czi_xml,
    )
    return file_information_execute(params, runner)


__all__ = [
    "FILE_INFORMATION_METADATA",
    "FileInformationOutputs",
    "file_information",
    "file_information_execute",
    "file_information_only_metadata_params",
    "file_information_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

CIFTI_TRANSPOSE_METADATA = Metadata(
    id="2184f40f0f6a338d14117c56093429c24502286f.boutiques",
    name="cifti-transpose",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


CiftiTransposeParameters = typing.TypedDict('CiftiTransposeParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/cifti-transpose"]],
    "cifti_in": InputPathType,
    "cifti_out": str,
    "opt_mem_limit_limit_gb": typing.NotRequired[float | None],
})
CiftiTransposeParametersTagged = typing.TypedDict('CiftiTransposeParametersTagged', {
    "@type": typing.Literal["workbench/cifti-transpose"],
    "cifti_in": InputPathType,
    "cifti_out": str,
    "opt_mem_limit_limit_gb": typing.NotRequired[float | None],
})


class CiftiTransposeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `CiftiTransposeParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_transpose_params(
    cifti_in: InputPathType,
    cifti_out: str,
    opt_mem_limit_limit_gb: float | None = None,
) -> CiftiTransposeParametersTagged:
    """
    Build parameters.
    
    Args:
        cifti_in: the input cifti file.
        cifti_out: the output cifti file.
        opt_mem_limit_limit_gb: restrict memory usage: memory limit in\
            gigabytes.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/cifti-transpose",
        "cifti_in": cifti_in,
        "cifti_out": cifti_out,
    }
    if opt_mem_limit_limit_gb is not None:
        params["opt_mem_limit_limit_gb"] = opt_mem_limit_limit_gb
    return params


def cifti_transpose_cargs(
    params: CiftiTransposeParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-transpose")
    cargs.append(execution.input_file(params.get("cifti_in", None)))
    cargs.append(params.get("cifti_out", None))
    if params.get("opt_mem_limit_limit_gb", None) is not None:
        cargs.extend([
            "-mem-limit",
            str(params.get("opt_mem_limit_limit_gb", None))
        ])
    return cargs


def cifti_transpose_outputs(
    params: CiftiTransposeParameters,
    execution: Execution,
) -> CiftiTransposeOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = CiftiTransposeOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(params.get("cifti_out", None)),
    )
    return ret


def cifti_transpose_execute(
    params: CiftiTransposeParameters,
    runner: Runner | None = None,
) -> CiftiTransposeOutputs:
    """
    cifti-transpose
    
    Transpose a cifti file.
    
    The input must be a 2-dimensional cifti file. The output is a cifti file
    where every row in the input is a column in the output.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiTransposeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_TRANSPOSE_METADATA)
    params = execution.params(params)
    cargs = cifti_transpose_cargs(params, execution)
    ret = cifti_transpose_outputs(params, execution)
    execution.run(cargs)
    return ret


def cifti_transpose(
    cifti_in: InputPathType,
    cifti_out: str,
    opt_mem_limit_limit_gb: float | None = None,
    runner: Runner | None = None,
) -> CiftiTransposeOutputs:
    """
    cifti-transpose
    
    Transpose a cifti file.
    
    The input must be a 2-dimensional cifti file. The output is a cifti file
    where every row in the input is a column in the output.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the input cifti file.
        cifti_out: the output cifti file.
        opt_mem_limit_limit_gb: restrict memory usage: memory limit in\
            gigabytes.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiTransposeOutputs`).
    """
    params = cifti_transpose_params(
        cifti_in=cifti_in,
        cifti_out=cifti_out,
        opt_mem_limit_limit_gb=opt_mem_limit_limit_gb,
    )
    return cifti_transpose_execute(params, runner)


__all__ = [
    "CIFTI_TRANSPOSE_METADATA",
    "CiftiTransposeOutputs",
    "cifti_transpose",
    "cifti_transpose_execute",
    "cifti_transpose_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_COORDINATES_TO_METRIC_METADATA = Metadata(
    id="5cba1432e52e6cde1dfbf6613fe3e4f9bb95feee.boutiques",
    name="surface-coordinates-to-metric",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceCoordinatesToMetricParameters = typing.TypedDict('SurfaceCoordinatesToMetricParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-coordinates-to-metric"]],
    "surface": InputPathType,
    "metric_out": str,
})
SurfaceCoordinatesToMetricParametersTagged = typing.TypedDict('SurfaceCoordinatesToMetricParametersTagged', {
    "@type": typing.Literal["workbench/surface-coordinates-to-metric"],
    "surface": InputPathType,
    "metric_out": str,
})


class SurfaceCoordinatesToMetricOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceCoordinatesToMetricParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def surface_coordinates_to_metric_params(
    surface: InputPathType,
    metric_out: str,
) -> SurfaceCoordinatesToMetricParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to use the coordinates of.
        metric_out: the output metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-coordinates-to-metric",
        "surface": surface,
        "metric_out": metric_out,
    }
    return params


def surface_coordinates_to_metric_cargs(
    params: SurfaceCoordinatesToMetricParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-coordinates-to-metric")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(params.get("metric_out", None))
    return cargs


def surface_coordinates_to_metric_outputs(
    params: SurfaceCoordinatesToMetricParameters,
    execution: Execution,
) -> SurfaceCoordinatesToMetricOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceCoordinatesToMetricOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def surface_coordinates_to_metric_execute(
    params: SurfaceCoordinatesToMetricParameters,
    runner: Runner | None = None,
) -> SurfaceCoordinatesToMetricOutputs:
    """
    surface-coordinates-to-metric
    
    Make metric file of surface coordinates.
    
    Puts the coordinates of the surface into a 3-map metric file, as x, y, z.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCoordinatesToMetricOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_COORDINATES_TO_METRIC_METADATA)
    params = execution.params(params)
    cargs = surface_coordinates_to_metric_cargs(params, execution)
    ret = surface_coordinates_to_metric_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_coordinates_to_metric(
    surface: InputPathType,
    metric_out: str,
    runner: Runner | None = None,
) -> SurfaceCoordinatesToMetricOutputs:
    """
    surface-coordinates-to-metric
    
    Make metric file of surface coordinates.
    
    Puts the coordinates of the surface into a 3-map metric file, as x, y, z.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to use the coordinates of.
        metric_out: the output metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceCoordinatesToMetricOutputs`).
    """
    params = surface_coordinates_to_metric_params(
        surface=surface,
        metric_out=metric_out,
    )
    return surface_coordinates_to_metric_execute(params, runner)


__all__ = [
    "SURFACE_COORDINATES_TO_METRIC_METADATA",
    "SurfaceCoordinatesToMetricOutputs",
    "surface_coordinates_to_metric",
    "surface_coordinates_to_metric_execute",
    "surface_coordinates_to_metric_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_SET_COORDINATES_METADATA = Metadata(
    id="72e93a016bdeefa39870b1c99e99dc40793bcdc3.boutiques",
    name="surface-set-coordinates",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceSetCoordinatesParameters = typing.TypedDict('SurfaceSetCoordinatesParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-set-coordinates"]],
    "surface_in": InputPathType,
    "coord_metric": InputPathType,
    "surface_out": str,
})
SurfaceSetCoordinatesParametersTagged = typing.TypedDict('SurfaceSetCoordinatesParametersTagged', {
    "@type": typing.Literal["workbench/surface-set-coordinates"],
    "surface_in": InputPathType,
    "coord_metric": InputPathType,
    "surface_out": str,
})


class SurfaceSetCoordinatesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceSetCoordinatesParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    surface_out: OutputPathType
    """the new surface"""


def surface_set_coordinates_params(
    surface_in: InputPathType,
    coord_metric: InputPathType,
    surface_out: str,
) -> SurfaceSetCoordinatesParametersTagged:
    """
    Build parameters.
    
    Args:
        surface_in: the surface to use for the topology.
        coord_metric: the new coordinates, as a 3-column metric file.
        surface_out: the new surface.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-set-coordinates",
        "surface_in": surface_in,
        "coord_metric": coord_metric,
        "surface_out": surface_out,
    }
    return params


def surface_set_coordinates_cargs(
    params: SurfaceSetCoordinatesParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-set-coordinates")
    cargs.append(execution.input_file(params.get("surface_in", None)))
    cargs.append(execution.input_file(params.get("coord_metric", None)))
    cargs.append(params.get("surface_out", None))
    return cargs


def surface_set_coordinates_outputs(
    params: SurfaceSetCoordinatesParameters,
    execution: Execution,
) -> SurfaceSetCoordinatesOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceSetCoordinatesOutputs(
        root=execution.output_file("."),
        surface_out=execution.output_file(params.get("surface_out", None)),
    )
    return ret


def surface_set_coordinates_execute(
    params: SurfaceSetCoordinatesParameters,
    runner: Runner | None = None,
) -> SurfaceSetCoordinatesOutputs:
    """
    surface-set-coordinates
    
    Modify coordinates of a surface.
    
    Takes the topology from an existing surface file, and uses values from a
    metric file as coordinates to construct a new surface file.
    
    See -surface-coordinates-to-metric for how to get surface coordinates as a
    metric file, such that you can then modify them via metric commands, etc.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceSetCoordinatesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_SET_COORDINATES_METADATA)
    params = execution.params(params)
    cargs = surface_set_coordinates_cargs(params, execution)
    ret = surface_set_coordinates_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_set_coordinates(
    surface_in: InputPathType,
    coord_metric: InputPathType,
    surface_out: str,
    runner: Runner | None = None,
) -> SurfaceSetCoordinatesOutputs:
    """
    surface-set-coordinates
    
    Modify coordinates of a surface.
    
    Takes the topology from an existing surface file, and uses values from a
    metric file as coordinates to construct a new surface file.
    
    See -surface-coordinates-to-metric for how to get surface coordinates as a
    metric file, such that you can then modify them via metric commands, etc.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface_in: the surface to use for the topology.
        coord_metric: the new coordinates, as a 3-column metric file.
        surface_out: the new surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceSetCoordinatesOutputs`).
    """
    params = surface_set_coordinates_params(
        surface_in=surface_in,
        coord_metric=coord_metric,
        surface_out=surface_out,
    )
    return surface_set_coordinates_execute(params, runner)


__all__ = [
    "SURFACE_SET_COORDINATES_METADATA",
    "SurfaceSetCoordinatesOutputs",
    "surface_set_coordinates",
    "surface_set_coordinates_execute",
    "surface_set_coordinates_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

METRIC_TFCE_METADATA = Metadata(
    id="924978b01979428d340e99932f7ca7e01166c2fb.boutiques",
    name="metric-tfce",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


MetricTfcePresmoothParameters = typing.TypedDict('MetricTfcePresmoothParameters', {
    "@type": typing.NotRequired[typing.Literal["presmooth"]],
    "kernel": float,
    "opt_fwhm": bool,
})
MetricTfcePresmoothParametersTagged = typing.TypedDict('MetricTfcePresmoothParametersTagged', {
    "@type": typing.Literal["presmooth"],
    "kernel": float,
    "opt_fwhm": bool,
})


MetricTfceParametersParameters = typing.TypedDict('MetricTfceParametersParameters', {
    "@type": typing.NotRequired[typing.Literal["parameters"]],
    "e": float,
    "h": float,
})
MetricTfceParametersParametersTagged = typing.TypedDict('MetricTfceParametersParametersTagged', {
    "@type": typing.Literal["parameters"],
    "e": float,
    "h": float,
})


MetricTfceParameters = typing.TypedDict('MetricTfceParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/metric-tfce"]],
    "surface": InputPathType,
    "metric_in": InputPathType,
    "metric_out": str,
    "presmooth": typing.NotRequired[MetricTfcePresmoothParameters | None],
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "parameters": typing.NotRequired[MetricTfceParametersParameters | None],
    "opt_column_column": typing.NotRequired[str | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})
MetricTfceParametersTagged = typing.TypedDict('MetricTfceParametersTagged', {
    "@type": typing.Literal["workbench/metric-tfce"],
    "surface": InputPathType,
    "metric_in": InputPathType,
    "metric_out": str,
    "presmooth": typing.NotRequired[MetricTfcePresmoothParameters | None],
    "opt_roi_roi_metric": typing.NotRequired[InputPathType | None],
    "parameters": typing.NotRequired[MetricTfceParametersParameters | None],
    "opt_column_column": typing.NotRequired[str | None],
    "opt_corrected_areas_area_metric": typing.NotRequired[InputPathType | None],
})


def metric_tfce_presmooth_params(
    kernel: float,
    opt_fwhm: bool = False,
) -> MetricTfcePresmoothParametersTagged:
    """
    Build parameters.
    
    Args:
        kernel: the size of the gaussian smoothing kernel in mm, as sigma by\
            default.
        opt_fwhm: kernel size is FWHM, not sigma.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "presmooth",
        "kernel": kernel,
        "opt_fwhm": opt_fwhm,
    }
    return params


def metric_tfce_presmooth_cargs(
    params: MetricTfcePresmoothParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-presmooth")
    cargs.append(str(params.get("kernel", None)))
    if params.get("opt_fwhm", False):
        cargs.append("-fwhm")
    return cargs


def metric_tfce_parameters_params(
    e: float,
    h: float,
) -> MetricTfceParametersParametersTagged:
    """
    Build parameters.
    
    Args:
        e: exponent for cluster area (default 1.0).
        h: exponent for threshold value (default 2.0).
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "parameters",
        "e": e,
        "h": h,
    }
    return params


def metric_tfce_parameters_cargs(
    params: MetricTfceParametersParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-parameters")
    cargs.append(str(params.get("e", None)))
    cargs.append(str(params.get("h", None)))
    return cargs


class MetricTfceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricTfceParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def metric_tfce_params(
    surface: InputPathType,
    metric_in: InputPathType,
    metric_out: str,
    presmooth: MetricTfcePresmoothParameters | None = None,
    opt_roi_roi_metric: InputPathType | None = None,
    parameters: MetricTfceParametersParameters | None = None,
    opt_column_column: str | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
) -> MetricTfceParametersTagged:
    """
    Build parameters.
    
    Args:
        surface: the surface to compute on.
        metric_in: the metric to run TFCE on.
        metric_out: the output metric.
        presmooth: smooth the metric before running TFCE.
        opt_roi_roi_metric: select a region of interest to run TFCE on: the\
            area to run TFCE on, as a metric.
        parameters: set parameters for TFCE integral.
        opt_column_column: select a single column: the column number or name.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/metric-tfce",
        "surface": surface,
        "metric_in": metric_in,
        "metric_out": metric_out,
    }
    if presmooth is not None:
        params["presmooth"] = presmooth
    if opt_roi_roi_metric is not None:
        params["opt_roi_roi_metric"] = opt_roi_roi_metric
    if parameters is not None:
        params["parameters"] = parameters
    if opt_column_column is not None:
        params["opt_column_column"] = opt_column_column
    if opt_corrected_areas_area_metric is not None:
        params["opt_corrected_areas_area_metric"] = opt_corrected_areas_area_metric
    return params


def metric_tfce_cargs(
    params: MetricTfceParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-tfce")
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(execution.input_file(params.get("metric_in", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("presmooth", None) is not None:
        cargs.extend(metric_tfce_presmooth_cargs(params.get("presmooth", None), execution))
    if params.get("opt_roi_roi_metric", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roi_metric", None))
        ])
    if params.get("parameters", None) is not None:
        cargs.extend(metric_tfce_parameters_cargs(params.get("parameters", None), execution))
    if params.get("opt_column_column", None) is not None:
        cargs.extend([
            "-column",
            params.get("opt_column_column", None)
        ])
    if params.get("opt_corrected_areas_area_metric", None) is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(params.get("opt_corrected_areas_area_metric", None))
        ])
    return cargs


def metric_tfce_outputs(
    params: MetricTfceParameters,
    execution: Execution,
) -> MetricTfceOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = MetricTfceOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def metric_tfce_execute(
    params: MetricTfceParameters,
    runner: Runner | None = None,
) -> MetricTfceOutputs:
    """
    metric-tfce
    
    Do tfce on a metric file.
    
    This command does not do any statistical analysis. Please use something like
    PALM if you are just trying to do statistics on your data.
    
    Threshold-free cluster enhancement is a method to increase the relative
    value of regions that would form clusters in a standard thresholding test.
    This is accomplished by evaluating the integral of:
    
    e(h, p)^E * h^H * dh
    
    at each vertex p, where h ranges from 0 to the maximum value in the data,
    and e(h, p) is the extent of the cluster containing vertex p at threshold h.
    Negative values are similarly enhanced by negating the data, running the
    same process, and negating the result.
    
    When using -presmooth with -corrected-areas, note that it is an approximate
    correction within the smoothing algorithm (the TFCE correction is exact).
    Doing smoothing on individual surfaces before averaging/TFCE is preferred,
    when possible, in order to better tie the smoothing kernel size to the
    original feature size.
    
    The TFCE method is explained in: Smith SM, Nichols TE., "Threshold-free
    cluster enhancement: addressing problems of smoothing, threshold dependence
    and localisation in cluster inference." Neuroimage. 2009 Jan 1;44(1):83-98.
    PMID: 18501637.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricTfceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_TFCE_METADATA)
    params = execution.params(params)
    cargs = metric_tfce_cargs(params, execution)
    ret = metric_tfce_outputs(params, execution)
    execution.run(cargs)
    return ret


def metric_tfce(
    surface: InputPathType,
    metric_in: InputPathType,
    metric_out: str,
    presmooth: MetricTfcePresmoothParameters | None = None,
    opt_roi_roi_metric: InputPathType | None = None,
    parameters: MetricTfceParametersParameters | None = None,
    opt_column_column: str | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> MetricTfceOutputs:
    """
    metric-tfce
    
    Do tfce on a metric file.
    
    This command does not do any statistical analysis. Please use something like
    PALM if you are just trying to do statistics on your data.
    
    Threshold-free cluster enhancement is a method to increase the relative
    value of regions that would form clusters in a standard thresholding test.
    This is accomplished by evaluating the integral of:
    
    e(h, p)^E * h^H * dh
    
    at each vertex p, where h ranges from 0 to the maximum value in the data,
    and e(h, p) is the extent of the cluster containing vertex p at threshold h.
    Negative values are similarly enhanced by negating the data, running the
    same process, and negating the result.
    
    When using -presmooth with -corrected-areas, note that it is an approximate
    correction within the smoothing algorithm (the TFCE correction is exact).
    Doing smoothing on individual surfaces before averaging/TFCE is preferred,
    when possible, in order to better tie the smoothing kernel size to the
    original feature size.
    
    The TFCE method is explained in: Smith SM, Nichols TE., "Threshold-free
    cluster enhancement: addressing problems of smoothing, threshold dependence
    and localisation in cluster inference." Neuroimage. 2009 Jan 1;44(1):83-98.
    PMID: 18501637.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to compute on.
        metric_in: the metric to run TFCE on.
        metric_out: the output metric.
        presmooth: smooth the metric before running TFCE.
        opt_roi_roi_metric: select a region of interest to run TFCE on: the\
            area to run TFCE on, as a metric.
        parameters: set parameters for TFCE integral.
        opt_column_column: select a single column: the column number or name.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricTfceOutputs`).
    """
    params = metric_tfce_params(
        surface=surface,
        metric_in=metric_in,
        metric_out=metric_out,
        presmooth=presmooth,
        opt_roi_roi_metric=opt_roi_roi_metric,
        parameters=parameters,
        opt_column_column=opt_column_column,
        opt_corrected_areas_area_metric=opt_corrected_areas_area_metric,
    )
    return metric_tfce_execute(params, runner)


__all__ = [
    "METRIC_TFCE_METADATA",
    "MetricTfceOutputs",
    "metric_tfce",
    "metric_tfce_execute",
    "metric_tfce_parameters_params",
    "metric_tfce_params",
    "metric_tfce_presmooth_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

VOLUME_FIND_CLUSTERS_METADATA = Metadata(
    id="363fad6e10e9a750a43bad790cd94f3805484d5d.boutiques",
    name="volume-find-clusters",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


VolumeFindClustersParameters = typing.TypedDict('VolumeFindClustersParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/volume-find-clusters"]],
    "volume_in": InputPathType,
    "value_threshold": float,
    "minimum_volume": float,
    "volume_out": str,
    "opt_less_than": bool,
    "opt_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "opt_subvolume_subvol": typing.NotRequired[str | None],
    "opt_size_ratio_ratio": typing.NotRequired[float | None],
    "opt_distance_distance": typing.NotRequired[float | None],
    "opt_start_startval": typing.NotRequired[int | None],
})
VolumeFindClustersParametersTagged = typing.TypedDict('VolumeFindClustersParametersTagged', {
    "@type": typing.Literal["workbench/volume-find-clusters"],
    "volume_in": InputPathType,
    "value_threshold": float,
    "minimum_volume": float,
    "volume_out": str,
    "opt_less_than": bool,
    "opt_roi_roi_volume": typing.NotRequired[InputPathType | None],
    "opt_subvolume_subvol": typing.NotRequired[str | None],
    "opt_size_ratio_ratio": typing.NotRequired[float | None],
    "opt_distance_distance": typing.NotRequired[float | None],
    "opt_start_startval": typing.NotRequired[int | None],
})


class VolumeFindClustersOutputs(typing.NamedTuple):
    """
    Output object returned when calling `VolumeFindClustersParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output volume"""


def volume_find_clusters_params(
    volume_in: InputPathType,
    value_threshold: float,
    minimum_volume: float,
    volume_out: str,
    opt_less_than: bool = False,
    opt_roi_roi_volume: InputPathType | None = None,
    opt_subvolume_subvol: str | None = None,
    opt_size_ratio_ratio: float | None = None,
    opt_distance_distance: float | None = None,
    opt_start_startval: int | None = None,
) -> VolumeFindClustersParametersTagged:
    """
    Build parameters.
    
    Args:
        volume_in: the input volume.
        value_threshold: threshold for data values.
        minimum_volume: threshold for cluster volume, in mm^3.
        volume_out: the output volume.
        opt_less_than: find values less than <value-threshold>, rather than\
            greater.
        opt_roi_roi_volume: select a region of interest: the roi, as a volume\
            file.
        opt_subvolume_subvol: select a single subvolume: the subvolume number\
            or name.
        opt_size_ratio_ratio: ignore clusters smaller than a given fraction of\
            the largest cluster in map: fraction of the largest cluster's volume.
        opt_distance_distance: ignore clusters further than a given distance\
            from the largest cluster: how far from the largest cluster a cluster\
            can be, edge to edge, in mm.
        opt_start_startval: start labeling clusters from a value other than 1:\
            the value to give the first cluster found.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/volume-find-clusters",
        "volume_in": volume_in,
        "value_threshold": value_threshold,
        "minimum_volume": minimum_volume,
        "volume_out": volume_out,
        "opt_less_than": opt_less_than,
    }
    if opt_roi_roi_volume is not None:
        params["opt_roi_roi_volume"] = opt_roi_roi_volume
    if opt_subvolume_subvol is not None:
        params["opt_subvolume_subvol"] = opt_subvolume_subvol
    if opt_size_ratio_ratio is not None:
        params["opt_size_ratio_ratio"] = opt_size_ratio_ratio
    if opt_distance_distance is not None:
        params["opt_distance_distance"] = opt_distance_distance
    if opt_start_startval is not None:
        params["opt_start_startval"] = opt_start_startval
    return params


def volume_find_clusters_cargs(
    params: VolumeFindClustersParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-find-clusters")
    cargs.append(execution.input_file(params.get("volume_in", None)))
    cargs.append(str(params.get("value_threshold", None)))
    cargs.append(str(params.get("minimum_volume", None)))
    cargs.append(params.get("volume_out", None))
    if params.get("opt_less_than", False):
        cargs.append("-less-than")
    if params.get("opt_roi_roi_volume", None) is not None:
        cargs.extend([
            "-roi",
            execution.input_file(params.get("opt_roi_roi_volume", None))
        ])
    if params.get("opt_subvolume_subvol", None) is not None:
        cargs.extend([
            "-subvolume",
            params.get("opt_subvolume_subvol", None)
        ])
    if params.get("opt_size_ratio_ratio", None) is not None:
        cargs.extend([
            "-size-ratio",
            str(params.get("opt_size_ratio_ratio", None))
        ])
    if params.get("opt_distance_distance", None) is not None:
        cargs.extend([
            "-distance",
            str(params.get("opt_distance_distance", None))
        ])
    if params.get("opt_start_startval", None) is not None:
        cargs.extend([
            "-start",
            str(params.get("opt_start_startval", None))
        ])
    return cargs


def volume_find_clusters_outputs(
    params: VolumeFindClustersParameters,
    execution: Execution,
) -> VolumeFindClustersOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = VolumeFindClustersOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(params.get("volume_out", None)),
    )
    return ret


def volume_find_clusters_execute(
    params: VolumeFindClustersParameters,
    runner: Runner | None = None,
) -> VolumeFindClustersOutputs:
    """
    volume-find-clusters
    
    Filter clusters by volume.
    
    Outputs a volume with nonzero integers for all voxels within a large enough
    cluster, and zeros elsewhere. The integers denote cluster membership (by
    default, first cluster found will use value 1, second cluster 2, etc).
    Cluster values are not reused across frames of the output, but instead keep
    counting up. By default, values greater than <value-threshold> are
    considered to be in a cluster, use -less-than to test for values less than
    the threshold. To apply this as a mask to the data, or to do more
    complicated thresholding, see -volume-math.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeFindClustersOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_FIND_CLUSTERS_METADATA)
    params = execution.params(params)
    cargs = volume_find_clusters_cargs(params, execution)
    ret = volume_find_clusters_outputs(params, execution)
    execution.run(cargs)
    return ret


def volume_find_clusters(
    volume_in: InputPathType,
    value_threshold: float,
    minimum_volume: float,
    volume_out: str,
    opt_less_than: bool = False,
    opt_roi_roi_volume: InputPathType | None = None,
    opt_subvolume_subvol: str | None = None,
    opt_size_ratio_ratio: float | None = None,
    opt_distance_distance: float | None = None,
    opt_start_startval: int | None = None,
    runner: Runner | None = None,
) -> VolumeFindClustersOutputs:
    """
    volume-find-clusters
    
    Filter clusters by volume.
    
    Outputs a volume with nonzero integers for all voxels within a large enough
    cluster, and zeros elsewhere. The integers denote cluster membership (by
    default, first cluster found will use value 1, second cluster 2, etc).
    Cluster values are not reused across frames of the output, but instead keep
    counting up. By default, values greater than <value-threshold> are
    considered to be in a cluster, use -less-than to test for values less than
    the threshold. To apply this as a mask to the data, or to do more
    complicated thresholding, see -volume-math.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: the input volume.
        value_threshold: threshold for data values.
        minimum_volume: threshold for cluster volume, in mm^3.
        volume_out: the output volume.
        opt_less_than: find values less than <value-threshold>, rather than\
            greater.
        opt_roi_roi_volume: select a region of interest: the roi, as a volume\
            file.
        opt_subvolume_subvol: select a single subvolume: the subvolume number\
            or name.
        opt_size_ratio_ratio: ignore clusters smaller than a given fraction of\
            the largest cluster in map: fraction of the largest cluster's volume.
        opt_distance_distance: ignore clusters further than a given distance\
            from the largest cluster: how far from the largest cluster a cluster\
            can be, edge to edge, in mm.
        opt_start_startval: start labeling clusters from a value other than 1:\
            the value to give the first cluster found.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeFindClustersOutputs`).
    """
    params = volume_find_clusters_params(
        volume_in=volume_in,
        value_threshold=value_threshold,
        minimum_volume=minimum_volume,
        volume_out=volume_out,
        opt_less_than=opt_less_than,
        opt_roi_roi_volume=opt_roi_roi_volume,
        opt_subvolume_subvol=opt_subvolume_subvol,
        opt_size_ratio_ratio=opt_size_ratio_ratio,
        opt_distance_distance=opt_distance_distance,
        opt_start_startval=opt_start_startval,
    )
    return volume_find_clusters_execute(params, runner)


__all__ = [
    "VOLUME_FIND_CLUSTERS_METADATA",
    "VolumeFindClustersOutputs",
    "volume_find_clusters",
    "volume_find_clusters_execute",
    "volume_find_clusters_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

ADD_TO_SPEC_FILE_METADATA = Metadata(
    id="70700f2e4a649b189d35240af30e2fe156a782f2.boutiques",
    name="add-to-spec-file",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


AddToSpecFileParameters = typing.TypedDict('AddToSpecFileParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/add-to-spec-file"]],
    "specfile": str,
    "structure": str,
    "filename": str,
})
AddToSpecFileParametersTagged = typing.TypedDict('AddToSpecFileParametersTagged', {
    "@type": typing.Literal["workbench/add-to-spec-file"],
    "specfile": str,
    "structure": str,
    "filename": str,
})


class AddToSpecFileOutputs(typing.NamedTuple):
    """
    Output object returned when calling `AddToSpecFileParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def add_to_spec_file_params(
    specfile: str,
    structure: str,
    filename: str,
) -> AddToSpecFileParametersTagged:
    """
    Build parameters.
    
    Args:
        specfile: the specification file to add to.
        structure: the structure of the data file.
        filename: the path to the file.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/add-to-spec-file",
        "specfile": specfile,
        "structure": structure,
        "filename": filename,
    }
    return params


def add_to_spec_file_cargs(
    params: AddToSpecFileParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-add-to-spec-file")
    cargs.append(params.get("specfile", None))
    cargs.append(params.get("structure", None))
    cargs.append(params.get("filename", None))
    return cargs


def add_to_spec_file_outputs(
    params: AddToSpecFileParameters,
    execution: Execution,
) -> AddToSpecFileOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = AddToSpecFileOutputs(
        root=execution.output_file("."),
    )
    return ret


def add_to_spec_file_execute(
    params: AddToSpecFileParameters,
    runner: Runner | None = None,
) -> AddToSpecFileOutputs:
    """
    add-to-spec-file
    
    Add a file to a specification file.
    
    The resulting spec file overwrites the existing spec file. If the spec file
    doesn't exist, it is created with default metadata. The structure argument
    must be one of the following:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AddToSpecFileOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADD_TO_SPEC_FILE_METADATA)
    params = execution.params(params)
    cargs = add_to_spec_file_cargs(params, execution)
    ret = add_to_spec_file_outputs(params, execution)
    execution.run(cargs)
    return ret


def add_to_spec_file(
    specfile: str,
    structure: str,
    filename: str,
    runner: Runner | None = None,
) -> AddToSpecFileOutputs:
    """
    add-to-spec-file
    
    Add a file to a specification file.
    
    The resulting spec file overwrites the existing spec file. If the spec file
    doesn't exist, it is created with default metadata. The structure argument
    must be one of the following:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT
    .
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        specfile: the specification file to add to.
        structure: the structure of the data file.
        filename: the path to the file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AddToSpecFileOutputs`).
    """
    params = add_to_spec_file_params(
        specfile=specfile,
        structure=structure,
        filename=filename,
    )
    return add_to_spec_file_execute(params, runner)


__all__ = [
    "ADD_TO_SPEC_FILE_METADATA",
    "AddToSpecFileOutputs",
    "add_to_spec_file",
    "add_to_spec_file_execute",
    "add_to_spec_file_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

SURFACE_APPLY_AFFINE_METADATA = Metadata(
    id="cbfa656451c57232ac09b2c71b92b95ea9448401.boutiques",
    name="surface-apply-affine",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


SurfaceApplyAffineFlirtParameters = typing.TypedDict('SurfaceApplyAffineFlirtParameters', {
    "@type": typing.NotRequired[typing.Literal["flirt"]],
    "source_volume": str,
    "target_volume": str,
})
SurfaceApplyAffineFlirtParametersTagged = typing.TypedDict('SurfaceApplyAffineFlirtParametersTagged', {
    "@type": typing.Literal["flirt"],
    "source_volume": str,
    "target_volume": str,
})


SurfaceApplyAffineParameters = typing.TypedDict('SurfaceApplyAffineParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/surface-apply-affine"]],
    "in_surf": InputPathType,
    "affine": str,
    "out_surf": str,
    "flirt": typing.NotRequired[SurfaceApplyAffineFlirtParameters | None],
})
SurfaceApplyAffineParametersTagged = typing.TypedDict('SurfaceApplyAffineParametersTagged', {
    "@type": typing.Literal["workbench/surface-apply-affine"],
    "in_surf": InputPathType,
    "affine": str,
    "out_surf": str,
    "flirt": typing.NotRequired[SurfaceApplyAffineFlirtParameters | None],
})


def surface_apply_affine_flirt_params(
    source_volume: str,
    target_volume: str,
) -> SurfaceApplyAffineFlirtParametersTagged:
    """
    Build parameters.
    
    Args:
        source_volume: the source volume used when generating the affine.
        target_volume: the target volume used when generating the affine.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "flirt",
        "source_volume": source_volume,
        "target_volume": target_volume,
    }
    return params


def surface_apply_affine_flirt_cargs(
    params: SurfaceApplyAffineFlirtParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("-flirt")
    cargs.append(params.get("source_volume", None))
    cargs.append(params.get("target_volume", None))
    return cargs


class SurfaceApplyAffineOutputs(typing.NamedTuple):
    """
    Output object returned when calling `SurfaceApplyAffineParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_surf: OutputPathType
    """the output transformed surface"""


def surface_apply_affine_params(
    in_surf: InputPathType,
    affine: str,
    out_surf: str,
    flirt: SurfaceApplyAffineFlirtParameters | None = None,
) -> SurfaceApplyAffineParametersTagged:
    """
    Build parameters.
    
    Args:
        in_surf: the surface to transform.
        affine: the affine file.
        out_surf: the output transformed surface.
        flirt: MUST be used if affine is a flirt affine.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/surface-apply-affine",
        "in_surf": in_surf,
        "affine": affine,
        "out_surf": out_surf,
    }
    if flirt is not None:
        params["flirt"] = flirt
    return params


def surface_apply_affine_cargs(
    params: SurfaceApplyAffineParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-apply-affine")
    cargs.append(execution.input_file(params.get("in_surf", None)))
    cargs.append(params.get("affine", None))
    cargs.append(params.get("out_surf", None))
    if params.get("flirt", None) is not None:
        cargs.extend(surface_apply_affine_flirt_cargs(params.get("flirt", None), execution))
    return cargs


def surface_apply_affine_outputs(
    params: SurfaceApplyAffineParameters,
    execution: Execution,
) -> SurfaceApplyAffineOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = SurfaceApplyAffineOutputs(
        root=execution.output_file("."),
        out_surf=execution.output_file(params.get("out_surf", None)),
    )
    return ret


def surface_apply_affine_execute(
    params: SurfaceApplyAffineParameters,
    runner: Runner | None = None,
) -> SurfaceApplyAffineOutputs:
    """
    surface-apply-affine
    
    Apply affine transform to surface file.
    
    For flirt matrices, you must use the -flirt option, because flirt matrices
    are not a complete description of the coordinate transform they represent.
    If the -flirt option is not present, the affine must be a nifti 'world'
    affine, which can be obtained with the -convert-affine command, or aff_conv
    from the 4dfp suite.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceApplyAffineOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_APPLY_AFFINE_METADATA)
    params = execution.params(params)
    cargs = surface_apply_affine_cargs(params, execution)
    ret = surface_apply_affine_outputs(params, execution)
    execution.run(cargs)
    return ret


def surface_apply_affine(
    in_surf: InputPathType,
    affine: str,
    out_surf: str,
    flirt: SurfaceApplyAffineFlirtParameters | None = None,
    runner: Runner | None = None,
) -> SurfaceApplyAffineOutputs:
    """
    surface-apply-affine
    
    Apply affine transform to surface file.
    
    For flirt matrices, you must use the -flirt option, because flirt matrices
    are not a complete description of the coordinate transform they represent.
    If the -flirt option is not present, the affine must be a nifti 'world'
    affine, which can be obtained with the -convert-affine command, or aff_conv
    from the 4dfp suite.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        in_surf: the surface to transform.
        affine: the affine file.
        out_surf: the output transformed surface.
        flirt: MUST be used if affine is a flirt affine.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceApplyAffineOutputs`).
    """
    params = surface_apply_affine_params(
        in_surf=in_surf,
        affine=affine,
        out_surf=out_surf,
        flirt=flirt,
    )
    return surface_apply_affine_execute(params, runner)


__all__ = [
    "SURFACE_APPLY_AFFINE_METADATA",
    "SurfaceApplyAffineOutputs",
    "surface_apply_affine",
    "surface_apply_affine_execute",
    "surface_apply_affine_flirt_params",
    "surface_apply_affine_params",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *

FOCI_GET_PROJECTION_VERTEX_METADATA = Metadata(
    id="fa9f290a6c602982e012db429ea537b40f61be20.boutiques",
    name="foci-get-projection-vertex",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


FociGetProjectionVertexParameters = typing.TypedDict('FociGetProjectionVertexParameters', {
    "@type": typing.NotRequired[typing.Literal["workbench/foci-get-projection-vertex"]],
    "foci": InputPathType,
    "surface": InputPathType,
    "metric_out": str,
    "opt_name_name": typing.NotRequired[str | None],
})
FociGetProjectionVertexParametersTagged = typing.TypedDict('FociGetProjectionVertexParametersTagged', {
    "@type": typing.Literal["workbench/foci-get-projection-vertex"],
    "foci": InputPathType,
    "surface": InputPathType,
    "metric_out": str,
    "opt_name_name": typing.NotRequired[str | None],
})


class FociGetProjectionVertexOutputs(typing.NamedTuple):
    """
    Output object returned when calling `FociGetProjectionVertexParameters(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric file"""


def foci_get_projection_vertex_params(
    foci: InputPathType,
    surface: InputPathType,
    metric_out: str,
    opt_name_name: str | None = None,
) -> FociGetProjectionVertexParametersTagged:
    """
    Build parameters.
    
    Args:
        foci: the foci file.
        surface: the surface related to the foci file.
        metric_out: the output metric file.
        opt_name_name: select a focus by name: the name of the focus.
    Returns:
        Parameter dictionary
    """
    params = {
        "@type": "workbench/foci-get-projection-vertex",
        "foci": foci,
        "surface": surface,
        "metric_out": metric_out,
    }
    if opt_name_name is not None:
        params["opt_name_name"] = opt_name_name
    return params


def foci_get_projection_vertex_cargs(
    params: FociGetProjectionVertexParameters,
    execution: Execution,
) -> list[str]:
    """
    Build command-line arguments from parameters.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Command-line arguments.
    """
    cargs = []
    cargs.append("wb_command")
    cargs.append("-foci-get-projection-vertex")
    cargs.append(execution.input_file(params.get("foci", None)))
    cargs.append(execution.input_file(params.get("surface", None)))
    cargs.append(params.get("metric_out", None))
    if params.get("opt_name_name", None) is not None:
        cargs.extend([
            "-name",
            params.get("opt_name_name", None)
        ])
    return cargs


def foci_get_projection_vertex_outputs(
    params: FociGetProjectionVertexParameters,
    execution: Execution,
) -> FociGetProjectionVertexOutputs:
    """
    Build outputs object containing output file paths and possibly stdout/stderr.
    
    Args:
        params: The parameters.
        execution: The execution object for resolving input paths.
    Returns:
        Outputs object.
    """
    ret = FociGetProjectionVertexOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(params.get("metric_out", None)),
    )
    return ret


def foci_get_projection_vertex_execute(
    params: FociGetProjectionVertexParameters,
    runner: Runner | None = None,
) -> FociGetProjectionVertexOutputs:
    """
    foci-get-projection-vertex
    
    Get projection vertex for foci.
    
    For each focus, a column is created in <metric-out>, and the vertex with the
    most influence on its projection is assigned a value of 1 in that column,
    with all other vertices 0. If -name is used, only one focus will be used.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        params: The parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FociGetProjectionVertexOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FOCI_GET_PROJECTION_VERTEX_METADATA)
    params = execution.params(params)
    cargs = foci_get_projection_vertex_cargs(params, execution)
    ret = foci_get_projection_vertex_outputs(params, execution)
    execution.run(cargs)
    return ret


def foci_get_projection_vertex(
    foci: InputPathType,
    surface: InputPathType,
    metric_out: str,
    opt_name_name: str | None = None,
    runner: Runner | None = None,
) -> FociGetProjectionVertexOutputs:
    """
    foci-get-projection-vertex
    
    Get projection vertex for foci.
    
    For each focus, a column is created in <metric-out>, and the vertex with the
    most influence on its projection is assigned a value of 1 in that column,
    with all other vertices 0. If -name is used, only one focus will be used.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        foci: the foci file.
        surface: the surface related to the foci file.
        metric_out: the output metric file.
        opt_name_name: select a focus by name: the name of the focus.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FociGetProjectionVertexOutputs`).
    """
    params = foci_get_projection_vertex_params(
        foci=foci,
        surface=surface,
        metric_out=metric_out,
        opt_name_name=opt_name_name,
    )
    return foci_get_projection_vertex_execute(params, runner)


__all__ = [
    "FOCI_GET_PROJECTION_VERTEX_METADATA",
    "FociGetProjectionVertexOutputs",
    "foci_get_projection_vertex",
    "foci_get_projection_vertex_execute",
    "foci_get_projection_vertex_params",
]
